@@ -1,10 +1,10 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
+ * contributor license agreements. See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * the License. You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -16,21 +16,18 @@
  */
 package org.apache.kafka.common.errors;
 
-public class OffsetOutOfRangeException extends ApiException {
+/**
+ * No reset policy has been defined, and the offsets for these partitions are either larger or smaller
+ * than the range of offsets the server has for the given partition.
+ */
+public class OffsetOutOfRangeException extends InvalidOffsetException {
 
     private static final long serialVersionUID = 1L;
 
-    public OffsetOutOfRangeException() {
-    }
-
     public OffsetOutOfRangeException(String message) {
         super(message);
     }
 
-    public OffsetOutOfRangeException(Throwable cause) {
-        super(cause);
-    }
-
     public OffsetOutOfRangeException(String message, Throwable cause) {
         super(message, cause);
     }
