@@ -44,6 +44,7 @@ import org.apache.kafka.common.serialization.StringDeserializer;
 import org.apache.kafka.common.utils.LogContext;
 import org.apache.kafka.common.utils.MockTime;
 import org.apache.kafka.test.TestUtils;
+
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
@@ -52,7 +53,6 @@ import org.junit.jupiter.params.provider.MethodSource;
 import org.mockito.Mockito;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -76,6 +76,7 @@ import static org.apache.kafka.clients.consumer.ConsumerConfig.VALUE_DESERIALIZE
 import static org.apache.kafka.clients.consumer.internals.ConsumerTestBuilder.DEFAULT_GROUP_ID;
 import static org.apache.kafka.clients.consumer.internals.ConsumerTestBuilder.DEFAULT_GROUP_INSTANCE_ID;
 import static org.apache.kafka.test.TestUtils.assertFutureThrows;
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertInstanceOf;
@@ -123,6 +124,48 @@ public class CommitRequestManagerTest {
         this.props.put(VALUE_DESERIALIZER_CLASS_CONFIG, StringDeserializer.class);
     }
 
+    @Test
+    public void testOffsetFetchRequestStateToStringBase() {
+        ConsumerConfig config = mock(ConsumerConfig.class);
+
+        CommitRequestManager commitRequestManager = new CommitRequestManager(
+                time,
+                logContext,
+                subscriptionState,
+                config,
+                coordinatorRequestManager,
+                offsetCommitCallbackInvoker,
+                DEFAULT_GROUP_ID,
+                Optional.of(DEFAULT_GROUP_INSTANCE_ID),
+                retryBackoffMs,
+                retryBackoffMaxMs,
+                OptionalDouble.of(0),
+                metrics);
+
+        commitRequestManager.onMemberEpochUpdated(Optional.of(1), Optional.empty());
+        Set<TopicPartition> requestedPartitions = Collections.singleton(new TopicPartition("topic-1", 1));
+
+        CommitRequestManager.OffsetFetchRequestState offsetFetchRequestState = commitRequestManager.createOffsetFetchRequest(requestedPartitions, 0);
+
+        TimedRequestState timedRequestState = new TimedRequestState(
+                logContext,
+                CommitRequestManager.class.getSimpleName(),
+                retryBackoffMs,
+                2,
+                retryBackoffMaxMs,
+                0,
+                TimedRequestState.deadlineTimer(time, 0)
+        );
+
+        String target = timedRequestState.toStringBase() +
+                ", " + offsetFetchRequestState.memberInfo +
+                ", requestedPartitions=" + offsetFetchRequestState.requestedPartitions;
+
+        assertDoesNotThrow(timedRequestState::toString);
+        assertFalse(target.contains("Optional"));
+        assertEquals(target, offsetFetchRequestState.toStringBase());
+    }
+
     @Test
     public void testPollSkipIfCoordinatorUnknown() {
         CommitRequestManager commitRequestManager = create(false, 0);
@@ -1065,6 +1108,44 @@ public class CommitRequestManagerTest {
         }
     }
 
+    @Test
+    public void testLastEpochSentOnCommit() {
+        // Enable auto-commit but with very long interval to avoid triggering auto-commits on the
+        // interval and just test the auto-commits triggered before revocation
+        CommitRequestManager commitRequestManager = create(true, Integer.MAX_VALUE);
+        when(coordinatorRequestManager.coordinator()).thenReturn(Optional.of(mockedNode));
+
+        TopicPartition tp = new TopicPartition("topic", 1);
+        subscriptionState.assignFromUser(singleton(tp));
+        subscriptionState.seek(tp, 100);
+
+        // Send auto commit to revoke partitions, expected to be retried on STALE_MEMBER_EPOCH
+        // with the latest epochs received (using long deadline to avoid expiring the request
+        // while retrying with the new epochs)
+        commitRequestManager.maybeAutoCommitSyncBeforeRevocation(Long.MAX_VALUE);
+
+        int initialEpoch = 1;
+        String memberId = "member1";
+        commitRequestManager.onMemberEpochUpdated(Optional.of(initialEpoch), Optional.of(memberId));
+
+        // Send request with epoch 1
+        completeOffsetCommitRequestWithError(commitRequestManager, Errors.STALE_MEMBER_EPOCH);
+        assertEquals(initialEpoch, commitRequestManager.lastEpochSentOnCommit().orElse(null));
+
+        // Receive new epoch. Last epoch sent should change only when sending out the next request
+        commitRequestManager.onMemberEpochUpdated(Optional.of(initialEpoch + 1), Optional.of(memberId));
+        assertEquals(initialEpoch, commitRequestManager.lastEpochSentOnCommit().get());
+        time.sleep(retryBackoffMs);
+        completeOffsetCommitRequestWithError(commitRequestManager, Errors.STALE_MEMBER_EPOCH);
+        assertEquals(initialEpoch + 1, commitRequestManager.lastEpochSentOnCommit().orElse(null));
+
+        // Receive empty epochs
+        commitRequestManager.onMemberEpochUpdated(Optional.empty(), Optional.empty());
+        time.sleep(retryBackoffMs * 2);
+        completeOffsetCommitRequestWithError(commitRequestManager, Errors.STALE_MEMBER_EPOCH);
+        assertFalse(commitRequestManager.lastEpochSentOnCommit().isPresent());
+    }
+
     @Test
     public void testEnsureCommitSensorRecordsMetric() {
         CommitRequestManager commitRequestManager = create(true, 100);
@@ -1377,7 +1458,7 @@ public class CommitRequestManagerTest {
                                                    long receivedTimeMs,
                                                    Errors error) {
         OffsetCommitResponseData responseData = new OffsetCommitResponseData()
-            .setTopics(Arrays.asList(
+            .setTopics(Collections.singletonList(
                 new OffsetCommitResponseData.OffsetCommitResponseTopic()
                     .setName(topic)
                     .setPartitions(Collections.singletonList(
@@ -1403,7 +1484,7 @@ public class CommitRequestManagerTest {
                                                                short apiKeyVersion,
                                                                NetworkClientDelegate.UnsentRequest unsentRequest) {
         OffsetCommitResponseData responseData = new OffsetCommitResponseData()
-            .setTopics(Arrays.asList(
+            .setTopics(Collections.singletonList(
                 new OffsetCommitResponseData.OffsetCommitResponseTopic()
                     .setName(topic)
                     .setPartitions(Collections.singletonList(
