@@ -16,67 +16,68 @@
  */
 package org.apache.kafka.connect.mirror;
 
-import java.util.HashMap;
-import java.util.Locale;
-import java.util.Map.Entry;
-
-import java.util.concurrent.atomic.AtomicReference;
 import org.apache.kafka.clients.admin.Admin;
+import org.apache.kafka.clients.admin.AlterConfigOp;
+import org.apache.kafka.clients.admin.Config;
+import org.apache.kafka.clients.admin.ConfigEntry;
+import org.apache.kafka.clients.admin.CreateTopicsOptions;
+import org.apache.kafka.clients.admin.NewPartitions;
+import org.apache.kafka.clients.admin.NewTopic;
+import org.apache.kafka.clients.admin.TopicDescription;
 import org.apache.kafka.clients.consumer.ConsumerConfig;
 import org.apache.kafka.common.IsolationLevel;
+import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.acl.AccessControlEntry;
+import org.apache.kafka.common.acl.AccessControlEntryFilter;
+import org.apache.kafka.common.acl.AclBinding;
+import org.apache.kafka.common.acl.AclBindingFilter;
+import org.apache.kafka.common.acl.AclOperation;
+import org.apache.kafka.common.acl.AclPermissionType;
+import org.apache.kafka.common.config.ConfigDef;
+import org.apache.kafka.common.config.ConfigResource;
 import org.apache.kafka.common.config.ConfigValue;
+import org.apache.kafka.common.errors.InvalidPartitionsException;
 import org.apache.kafka.common.errors.SecurityDisabledException;
+import org.apache.kafka.common.errors.UnsupportedVersionException;
+import org.apache.kafka.common.resource.PatternType;
+import org.apache.kafka.common.resource.ResourcePattern;
+import org.apache.kafka.common.resource.ResourcePatternFilter;
+import org.apache.kafka.common.resource.ResourceType;
+import org.apache.kafka.common.utils.AppInfoParser;
+import org.apache.kafka.common.utils.Utils;
 import org.apache.kafka.connect.connector.Task;
 import org.apache.kafka.connect.errors.ConnectException;
 import org.apache.kafka.connect.source.ExactlyOnceSupport;
 import org.apache.kafka.connect.source.SourceConnector;
-import org.apache.kafka.common.config.ConfigDef;
-import org.apache.kafka.common.config.ConfigResource;
-import org.apache.kafka.common.acl.AclBinding;
-import org.apache.kafka.common.acl.AclBindingFilter;
-import org.apache.kafka.common.acl.AccessControlEntry;
-import org.apache.kafka.common.acl.AccessControlEntryFilter;
-import org.apache.kafka.common.acl.AclPermissionType;
-import org.apache.kafka.common.acl.AclOperation;
-import org.apache.kafka.common.resource.ResourceType;
-import org.apache.kafka.common.resource.ResourcePattern;
-import org.apache.kafka.common.resource.ResourcePatternFilter;
-import org.apache.kafka.common.resource.PatternType;
-import org.apache.kafka.common.TopicPartition;
-import org.apache.kafka.common.errors.InvalidPartitionsException;
-import org.apache.kafka.common.errors.UnsupportedVersionException;
-import org.apache.kafka.common.utils.AppInfoParser;
-import org.apache.kafka.common.utils.Utils;
-import org.apache.kafka.clients.admin.AlterConfigOp;
-import org.apache.kafka.clients.admin.TopicDescription;
-import org.apache.kafka.clients.admin.Config;
-import org.apache.kafka.clients.admin.ConfigEntry;
-import org.apache.kafka.clients.admin.NewPartitions;
-import org.apache.kafka.clients.admin.NewTopic;
-import org.apache.kafka.clients.admin.CreateTopicsOptions;
-
-import java.util.Map;
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Objects;
-import java.util.Optional;
-import java.util.Set;
-import java.util.HashSet;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.function.Function;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
-import java.util.stream.Stream;
-import java.util.concurrent.ExecutionException;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Map.Entry;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Set;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+import java.util.stream.IntStream;
+import java.util.stream.Stream;
+
+import static org.apache.kafka.connect.mirror.MirrorConnectorConfig.OFFSET_SYNCS_CLIENT_ROLE_PREFIX;
+import static org.apache.kafka.connect.mirror.MirrorConnectorConfig.OFFSET_SYNCS_TOPIC_CONFIG_PREFIX;
 import static org.apache.kafka.connect.mirror.MirrorSourceConfig.SYNC_TOPIC_ACLS_ENABLED;
 import static org.apache.kafka.connect.mirror.MirrorUtils.SOURCE_CLUSTER_KEY;
 import static org.apache.kafka.connect.mirror.MirrorUtils.TOPIC_KEY;
+import static org.apache.kafka.connect.mirror.MirrorUtils.adminCall;
 
 /** Replicate data, configuration, and ACLs between clusters.
  *
@@ -88,9 +89,11 @@ public class MirrorSourceConnector extends SourceConnector {
     private static final ResourcePatternFilter ANY_TOPIC = new ResourcePatternFilter(ResourceType.TOPIC,
         null, PatternType.ANY);
     private static final AclBindingFilter ANY_TOPIC_ACL = new AclBindingFilter(ANY_TOPIC, AccessControlEntryFilter.ANY);
-    private static final String READ_COMMITTED = IsolationLevel.READ_COMMITTED.toString().toLowerCase(Locale.ROOT);
+    private static final String READ_COMMITTED = IsolationLevel.READ_COMMITTED.toString();
     private static final String EXACTLY_ONCE_SUPPORT_CONFIG = "exactly.once.support";
 
+    private final AtomicBoolean noAclAuthorizer = new AtomicBoolean(false);
+
     private Scheduler scheduler;
     private MirrorSourceConfig config;
     private SourceAndTarget sourceAndTarget;
@@ -103,9 +106,7 @@ public class MirrorSourceConnector extends SourceConnector {
     private int replicationFactor;
     private Admin sourceAdminClient;
     private Admin targetAdminClient;
-    private Admin offsetSyncsAdminClient;
     private volatile boolean useIncrementalAlterConfigs;
-    private AtomicBoolean noAclAuthorizer = new AtomicBoolean(false);
 
     public MirrorSourceConnector() {
         // nop
@@ -139,9 +140,10 @@ public class MirrorSourceConnector extends SourceConnector {
     }
         
     // visible for testing
-    MirrorSourceConnector(Admin sourceAdminClient, Admin targetAdminClient) {
+    MirrorSourceConnector(Admin sourceAdminClient, Admin targetAdminClient, MirrorSourceConfig config) {
         this.sourceAdminClient = sourceAdminClient;
         this.targetAdminClient = targetAdminClient;
+        this.config = config;
     }
 
     @Override
@@ -160,7 +162,7 @@ public class MirrorSourceConnector extends SourceConnector {
         sourceAdminClient = config.forwardingAdmin(config.sourceAdminConfig("replication-source-admin"));
         targetAdminClient = config.forwardingAdmin(config.targetAdminConfig("replication-target-admin"));
         useIncrementalAlterConfigs =  !config.useIncrementalAlterConfigs().equals(MirrorSourceConfig.NEVER_USE_INCREMENTAL_ALTER_CONFIGS);
-        offsetSyncsAdminClient = config.forwardingAdmin(config.offsetSyncsTopicAdminConfig());
+
         scheduler = new Scheduler(getClass(), config.entityLabel(), config.adminTimeout());
         scheduler.execute(this::createOffsetSyncsTopic, "creating upstream offset-syncs topic");
         scheduler.execute(this::loadTopicPartitions, "loading initial set of topic-partitions");
@@ -186,7 +188,6 @@ public class MirrorSourceConnector extends SourceConnector {
         Utils.closeQuietly(configPropertyFilter, "config property filter");
         Utils.closeQuietly(sourceAdminClient, "source admin client");
         Utils.closeQuietly(targetAdminClient, "target admin client");
-        Utils.closeQuietly(offsetSyncsAdminClient, "offset syncs admin client");
         log.info("Stopping {} took {} ms.", connectorName, System.currentTimeMillis() - start);
     }
 
@@ -233,6 +234,30 @@ public class MirrorSourceConnector extends SourceConnector {
     @Override
     public org.apache.kafka.common.config.Config validate(Map<String, String> props) {
         List<ConfigValue> configValues = super.validate(props).configValues();
+        validateExactlyOnceConfigs(props, configValues);
+        validateEmitOffsetSyncConfigs(props, configValues);
+
+        return new org.apache.kafka.common.config.Config(configValues);
+    }
+
+    private static void validateEmitOffsetSyncConfigs(Map<String, String> props, List<ConfigValue> configValues) {
+        boolean offsetSyncsConfigured = props.keySet().stream()
+                .anyMatch(conf -> conf.startsWith(OFFSET_SYNCS_CLIENT_ROLE_PREFIX) || conf.startsWith(OFFSET_SYNCS_TOPIC_CONFIG_PREFIX));
+
+        if ("false".equals(props.get(MirrorConnectorConfig.EMIT_OFFSET_SYNCS_ENABLED)) && offsetSyncsConfigured) {
+            ConfigValue emitOffsetSyncs = configValues.stream().filter(prop -> MirrorConnectorConfig.EMIT_OFFSET_SYNCS_ENABLED.equals(prop.name()))
+                    .findAny()
+                    .orElseGet(() -> {
+                        ConfigValue result = new ConfigValue(MirrorConnectorConfig.EMIT_OFFSET_SYNCS_ENABLED);
+                        configValues.add(result);
+                        return result;
+                    });
+            emitOffsetSyncs.addErrorMessage("MirrorSourceConnector can't setup offset-syncs feature while " +
+                    MirrorConnectorConfig.EMIT_OFFSET_SYNCS_ENABLED + " set to false");
+        }
+    }
+
+    private void validateExactlyOnceConfigs(Map<String, String> props, List<ConfigValue> configValues) {
         if ("required".equals(props.get(EXACTLY_ONCE_SUPPORT_CONFIG))) {
             if (!consumerUsesReadCommitted(props)) {
                 ConfigValue exactlyOnceSupport = configValues.stream()
@@ -255,7 +280,6 @@ public class MirrorSourceConnector extends SourceConnector {
                 );
             }
         }
-        return new org.apache.kafka.common.config.Config(configValues);
     }
 
     @Override
@@ -429,11 +453,15 @@ public class MirrorSourceConnector extends SourceConnector {
     }
 
     private void createOffsetSyncsTopic() {
-        MirrorUtils.createSinglePartitionCompactedTopic(
-                config.offsetSyncsTopic(),
-                config.offsetSyncsTopicReplicationFactor(),
-                offsetSyncsAdminClient
-        );
+        if (config.emitOffsetSyncsEnabled()) {
+            try (Admin offsetSyncsAdminClient = config.forwardingAdmin(config.offsetSyncsTopicAdminConfig())) {
+                MirrorUtils.createSinglePartitionCompactedTopic(
+                        config.offsetSyncsTopic(),
+                        config.offsetSyncsTopicReplicationFactor(),
+                        offsetSyncsAdminClient
+                );
+            }
+        }
     }
 
     void computeAndCreateTopicPartitions() throws ExecutionException, InterruptedException {
@@ -495,59 +523,83 @@ public class MirrorSourceConnector extends SourceConnector {
     }
 
     // visible for testing
-    void createNewTopics(Map<String, NewTopic> newTopics) {
-        targetAdminClient.createTopics(newTopics.values(), new CreateTopicsOptions()).values().forEach((k, v) -> v.whenComplete((x, e) -> {
-            if (e != null) {
-                log.warn("Could not create topic {}.", k, e);
-            } else {
-                log.info("Created remote topic {} with {} partitions.", k, newTopics.get(k).numPartitions());
-            }
-        }));
+    void createNewTopics(Map<String, NewTopic> newTopics) throws ExecutionException, InterruptedException {
+        adminCall(
+                () -> {
+                    targetAdminClient.createTopics(newTopics.values(), new CreateTopicsOptions()).values()
+                            .forEach((k, v) -> v.whenComplete((x, e) -> {
+                                if (e != null) {
+                                    log.warn("Could not create topic {}.", k, e);
+                                } else {
+                                    log.info("Created remote topic {} with {} partitions.", k, newTopics.get(k).numPartitions());
+                                }
+                            }));
+                    return null;
+                },
+                () -> String.format("create topics %s on %s cluster", newTopics, config.targetClusterAlias())
+        );
     }
 
-    void createNewPartitions(Map<String, NewPartitions> newPartitions) {
-        targetAdminClient.createPartitions(newPartitions).values().forEach((k, v) -> v.whenComplete((x, e) -> {
-            if (e instanceof InvalidPartitionsException) {
-                // swallow, this is normal
-            } else if (e != null) {
-                log.warn("Could not create topic-partitions for {}.", k, e);
-            } else {
-                log.info("Increased size of {} to {} partitions.", k, newPartitions.get(k).totalCount());
-            }
-        }));
+    void createNewPartitions(Map<String, NewPartitions> newPartitions) throws ExecutionException, InterruptedException {
+        adminCall(
+                () -> {
+                    targetAdminClient.createPartitions(newPartitions).values().forEach((k, v) -> v.whenComplete((x, e) -> {
+                        if (e instanceof InvalidPartitionsException) {
+                            // swallow, this is normal
+                        } else if (e != null) {
+                            log.warn("Could not create topic-partitions for {}.", k, e);
+                        } else {
+                            log.info("Increased size of {} to {} partitions.", k, newPartitions.get(k).totalCount());
+                        }
+                    }));
+                    return null;
+                },
+                () -> String.format("create partitions %s on %s cluster", newPartitions, config.targetClusterAlias())
+        );
     }
 
     private Set<String> listTopics(Admin adminClient)
             throws InterruptedException, ExecutionException {
-        return adminClient.listTopics().names().get();
+        return adminCall(
+                () -> adminClient.listTopics().names().get(),
+                () -> "list topics on " + actualClusterAlias(adminClient) + " cluster"
+        );
     }
 
     private Optional<Collection<AclBinding>> listTopicAclBindings()
             throws InterruptedException, ExecutionException {
-        Collection<AclBinding> bindings;
-        try {
-            bindings = sourceAdminClient.describeAcls(ANY_TOPIC_ACL).values().get();
-        } catch (ExecutionException e) {
-            if (e.getCause() instanceof SecurityDisabledException) {
-                if (noAclAuthorizer.compareAndSet(false, true)) {
-                    log.info(
-                            "No ACL authorizer is configured on the source Kafka cluster, so no topic ACL syncing will take place. "
-                                    + "Consider disabling topic ACL syncing by setting " + SYNC_TOPIC_ACLS_ENABLED + " to 'false'."
-                    );
-                } else {
-                    log.debug("Source-side ACL authorizer still not found; skipping topic ACL sync");
-                }
-                return Optional.empty();
-            } else {
-                throw e;
-            }
-        }
-        return Optional.of(bindings);
+        return adminCall(
+                () -> {
+                    Collection<AclBinding> bindings;
+                    try {
+                        bindings = sourceAdminClient.describeAcls(ANY_TOPIC_ACL).values().get();
+                    } catch (ExecutionException e) {
+                        if (e.getCause() instanceof SecurityDisabledException) {
+                            if (noAclAuthorizer.compareAndSet(false, true)) {
+                                log.info(
+                                        "No ACL authorizer is configured on the source Kafka cluster, so no topic ACL syncing will take place. "
+                                                + "Consider disabling topic ACL syncing by setting " + SYNC_TOPIC_ACLS_ENABLED + " to 'false'."
+                                );
+                            } else {
+                                log.debug("Source-side ACL authorizer still not found; skipping topic ACL sync");
+                            }
+                            return Optional.empty();
+                        } else {
+                            throw e;
+                        }
+                    }
+                    return Optional.of(bindings);
+                },
+                () -> "describe ACLs on " + config.sourceClusterAlias() + " cluster"
+        );
     }
 
-    private static Collection<TopicDescription> describeTopics(Admin adminClient, Collection<String> topics)
+    private Collection<TopicDescription> describeTopics(Admin adminClient, Collection<String> topics)
             throws InterruptedException, ExecutionException {
-        return adminClient.describeTopics(topics).allTopicNames().get().values();
+        return adminCall(
+                () -> adminClient.describeTopics(topics).allTopicNames().get().values(),
+                () -> String.format("describe topics %s on %s cluster", topics, actualClusterAlias(adminClient))
+        );
     }
 
     static Map<String, String> configToMap(Config config) {
@@ -558,20 +610,26 @@ public class MirrorSourceConnector extends SourceConnector {
     // visible for testing
     // use deprecated alterConfigs API for broker compatibility back to 0.11.0
     @SuppressWarnings("deprecation")
-    void deprecatedAlterConfigs(Map<String, Config> topicConfigs) {
+    void deprecatedAlterConfigs(Map<String, Config> topicConfigs) throws ExecutionException, InterruptedException {
         Map<ConfigResource, Config> configs = topicConfigs.entrySet().stream()
             .collect(Collectors.toMap(x ->
                 new ConfigResource(ConfigResource.Type.TOPIC, x.getKey()), Entry::getValue));
         log.trace("Syncing configs for {} topics.", configs.size());
-        targetAdminClient.alterConfigs(configs).values().forEach((k, v) -> v.whenComplete((x, e) -> {
-            if (e != null) {
-                log.warn("Could not alter configuration of topic {}.", k.name(), e);
-            }
-        }));
+        adminCall(
+                () -> {
+                    targetAdminClient.alterConfigs(configs).values().forEach((k, v) -> v.whenComplete((x, e) -> {
+                        if (e != null) {
+                            log.warn("Could not alter configuration of topic {}.", k.name(), e);
+                        }
+                    }));
+                    return null;
+                },
+                () -> String.format("alter topic configs %s on %s cluster", topicConfigs, config.targetClusterAlias())
+        );
     }
 
     // visible for testing
-    void incrementalAlterConfigs(Map<String, Config> topicConfigs) {
+    void incrementalAlterConfigs(Map<String, Config> topicConfigs) throws ExecutionException, InterruptedException {
         Map<ConfigResource, Collection<AlterConfigOp>> configOps = new HashMap<>();
         for (Map.Entry<String, Config> topicConfig : topicConfigs.entrySet()) {
             Collection<AlterConfigOp> ops = new ArrayList<>();
@@ -587,36 +645,48 @@ public class MirrorSourceConnector extends SourceConnector {
         }
         log.trace("Syncing configs for {} topics.", configOps.size());
         AtomicReference<Boolean> encounteredError = new AtomicReference<>(false);
-        targetAdminClient.incrementalAlterConfigs(configOps).values().forEach((k, v) -> v.whenComplete((x, e) -> {
-            if (e != null) {
-                if (config.useIncrementalAlterConfigs().equals(MirrorSourceConfig.REQUEST_INCREMENTAL_ALTER_CONFIGS)
-                        && e instanceof UnsupportedVersionException && !encounteredError.get()) {
-                    //Fallback logic
-                    log.warn("The target cluster {} is not compatible with IncrementalAlterConfigs API. "
-                            + "Therefore using deprecated AlterConfigs API for syncing configs for topic {}",
-                            sourceAndTarget.target(), k.name(), e);
-                    encounteredError.set(true);
-                    useIncrementalAlterConfigs = false;
-                } else if (config.useIncrementalAlterConfigs().equals(MirrorSourceConfig.REQUIRE_INCREMENTAL_ALTER_CONFIGS)
-                        && e instanceof UnsupportedVersionException && !encounteredError.get()) {
-                    log.error("Failed to sync configs for topic {} on cluster {} with IncrementalAlterConfigs API", k.name(), sourceAndTarget.target(), e);
-                    encounteredError.set(true);
-                    context.raiseError(new ConnectException("use.incremental.alter.configs was set to \"required\", but the target cluster '"
-                            + sourceAndTarget.target() + "' is not compatible with IncrementalAlterConfigs API", e));
-                } else {
-                    log.warn("Could not alter configuration of topic {}.", k.name(), e);
-                }
-            }
-        }));
+        adminCall(
+                () -> {
+                    targetAdminClient.incrementalAlterConfigs(configOps).values().forEach((k, v) -> v.whenComplete((x, e) -> {
+                        if (e != null) {
+                            if (config.useIncrementalAlterConfigs().equals(MirrorSourceConfig.REQUEST_INCREMENTAL_ALTER_CONFIGS)
+                                    && e instanceof UnsupportedVersionException && !encounteredError.get()) {
+                                //Fallback logic
+                                log.warn("The target cluster {} is not compatible with IncrementalAlterConfigs API. "
+                                                + "Therefore using deprecated AlterConfigs API for syncing configs for topic {}",
+                                        sourceAndTarget.target(), k.name(), e);
+                                encounteredError.set(true);
+                                useIncrementalAlterConfigs = false;
+                            } else if (config.useIncrementalAlterConfigs().equals(MirrorSourceConfig.REQUIRE_INCREMENTAL_ALTER_CONFIGS)
+                                    && e instanceof UnsupportedVersionException && !encounteredError.get()) {
+                                log.error("Failed to sync configs for topic {} on cluster {} with IncrementalAlterConfigs API", k.name(), sourceAndTarget.target(), e);
+                                encounteredError.set(true);
+                                context.raiseError(new ConnectException("use.incremental.alter.configs was set to \"required\", but the target cluster '"
+                                        + sourceAndTarget.target() + "' is not compatible with IncrementalAlterConfigs API", e));
+                            } else {
+                                log.warn("Could not alter configuration of topic {}.", k.name(), e);
+                            }
+                        }
+                    }));
+                    return null;
+                },
+                () -> String.format("incremental alter topic configs %s on %s cluster", topicConfigs, config.targetClusterAlias())
+        );
     }
 
-    private void updateTopicAcls(List<AclBinding> bindings) {
+    private void updateTopicAcls(List<AclBinding> bindings) throws ExecutionException, InterruptedException {
         log.trace("Syncing {} topic ACL bindings.", bindings.size());
-        targetAdminClient.createAcls(bindings).values().forEach((k, v) -> v.whenComplete((x, e) -> {
-            if (e != null) {
-                log.warn("Could not sync ACL of topic {}.", k.pattern().name(), e);
-            }
-        }));
+        adminCall(
+                () -> {
+                    targetAdminClient.createAcls(bindings).values().forEach((k, v) -> v.whenComplete((x, e) -> {
+                        if (e != null) {
+                            log.warn("Could not sync ACL of topic {}.", k.pattern().name(), e);
+                        }
+                    }));
+                    return null;
+                },
+                () -> String.format("create ACLs %s on %s cluster", bindings, config.targetClusterAlias())
+        );
     }
 
     private static Stream<TopicPartition> expandTopicDescription(TopicDescription description) {
@@ -630,8 +700,11 @@ public class MirrorSourceConnector extends SourceConnector {
         Set<ConfigResource> resources = topics.stream()
             .map(x -> new ConfigResource(ConfigResource.Type.TOPIC, x))
             .collect(Collectors.toSet());
-        return sourceAdminClient.describeConfigs(resources).all().get().entrySet().stream()
-            .collect(Collectors.toMap(x -> x.getKey().name(), Entry::getValue));
+        return adminCall(
+                () -> sourceAdminClient.describeConfigs(resources).all().get().entrySet().stream()
+                        .collect(Collectors.toMap(x -> x.getKey().name(), Entry::getValue)),
+                () -> String.format("describe configs for topics %s on %s cluster", topics, config.sourceClusterAlias())
+        );
     }
 
     Config targetConfig(Config sourceConfig, boolean incremental) {
@@ -701,4 +774,8 @@ public class MirrorSourceConnector extends SourceConnector {
     String formatRemoteTopic(String topic) {
         return replicationPolicy.formatRemoteTopic(sourceAndTarget.source(), topic);
     }
+
+    private String actualClusterAlias(Admin adminClient) {
+        return adminClient.equals(sourceAdminClient) ? config.sourceClusterAlias() : config.targetClusterAlias();
+    }
 }
