@@ -25,19 +25,24 @@ import org.apache.kafka.common.metrics.stats.Frequencies;
 import org.apache.kafka.common.metrics.stats.Max;
 import org.apache.kafka.common.utils.Time;
 import org.apache.kafka.common.utils.Utils;
-import org.apache.kafka.connect.runtime.errors.ErrorHandlingMetrics;
+import org.apache.kafka.connect.connector.ConnectRecord;
 import org.apache.kafka.connect.runtime.AbstractStatus.State;
 import org.apache.kafka.connect.runtime.ConnectMetrics.MetricGroup;
+import org.apache.kafka.connect.runtime.errors.ErrorHandlingMetrics;
+import org.apache.kafka.connect.runtime.errors.ErrorReporter;
 import org.apache.kafka.connect.runtime.errors.RetryWithToleranceOperator;
 import org.apache.kafka.connect.storage.StatusBackingStore;
 import org.apache.kafka.connect.util.ConnectorTaskId;
 import org.apache.kafka.connect.util.LoggingContext;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.List;
 import java.util.Locale;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
+import java.util.function.Supplier;
 
 /**
  * Handles processing for an individual task. This interface only provides the basic methods
@@ -49,8 +54,10 @@ import java.util.concurrent.TimeUnit;
  * asynchronous (e.g. pause/resume). For example, changing the state to paused could cause a race
  * if the task fails at the same time. To protect from these cases, we synchronize status updates
  * using the WorkerTask's monitor.
+ * @param <T> The type of record initially entering the processing pipeline from the source or consumer
+ * @param <R> The type of record during transformations (must be an implementation of {@link ConnectRecord})
  */
-abstract class WorkerTask implements Runnable {
+abstract class WorkerTask<T, R extends ConnectRecord<R>> implements Runnable {
     private static final Logger log = LoggerFactory.getLogger(WorkerTask.class);
     private static final String THREAD_NAME_PREFIX = "task-thread-";
 
@@ -66,8 +73,9 @@ abstract class WorkerTask implements Runnable {
     private volatile boolean stopping;   // indicates whether the Worker has asked the task to stop
     private volatile boolean cancelled;  // indicates whether the Worker has cancelled the task (e.g. because of slow shutdown)
     private final ErrorHandlingMetrics errorMetrics;
-
-    protected final RetryWithToleranceOperator retryWithToleranceOperator;
+    protected final RetryWithToleranceOperator<T> retryWithToleranceOperator;
+    protected final TransformationChain<T, R> transformationChain;
+    private final Supplier<List<ErrorReporter<T>>> errorReportersSupplier;
 
     public WorkerTask(ConnectorTaskId id,
                       TaskStatus.Listener statusListener,
@@ -75,7 +83,9 @@ abstract class WorkerTask implements Runnable {
                       ClassLoader loader,
                       ConnectMetrics connectMetrics,
                       ErrorHandlingMetrics errorMetrics,
-                      RetryWithToleranceOperator retryWithToleranceOperator,
+                      RetryWithToleranceOperator<T> retryWithToleranceOperator,
+                      TransformationChain<T, R> transformationChain,
+                      Supplier<List<ErrorReporter<T>>> errorReportersSupplier,
                       Time time,
                       StatusBackingStore statusBackingStore) {
         this.id = id;
@@ -89,6 +99,8 @@ abstract class WorkerTask implements Runnable {
         this.cancelled = false;
         this.taskMetricsGroup.recordState(this.targetState);
         this.retryWithToleranceOperator = retryWithToleranceOperator;
+        this.transformationChain = transformationChain;
+        this.errorReportersSupplier = errorReportersSupplier;
         this.time = time;
         this.statusBackingStore = statusBackingStore;
     }
@@ -158,6 +170,13 @@ abstract class WorkerTask implements Runnable {
         Utils.closeQuietly(errorMetrics, "Error handling metrics");
     }
 
+    // Visible for testing
+    void doStart() {
+        retryWithToleranceOperator.reporters(errorReportersSupplier.get());
+        initializeAndStart();
+        statusListener.onStartup(id);
+    }
+
     protected abstract void initializeAndStart();
 
     protected abstract void execute();
@@ -178,12 +197,16 @@ abstract class WorkerTask implements Runnable {
         return cancelled;
     }
 
-    private void doClose() {
+    // Visible for testing
+    void doClose() {
         try {
             close();
         } catch (Throwable t) {
             log.error("{} Task threw an uncaught and unrecoverable exception during shutdown", this, t);
             throw t;
+        } finally {
+            Utils.closeQuietly(transformationChain, "transformation chain");
+            Utils.closeQuietly(retryWithToleranceOperator, "retry operator");
         }
     }
 
@@ -199,8 +222,7 @@ abstract class WorkerTask implements Runnable {
                 }
             }
 
-            initializeAndStart();
-            statusListener.onStartup(id);
+            doStart();
             execute();
         } catch (Throwable t) {
             failed = true;
