@@ -19,18 +19,19 @@ package org.apache.kafka.connect.runtime;
 import org.apache.kafka.connect.source.SourceRecord;
 import org.apache.kafka.connect.transforms.Transformation;
 import org.apache.kafka.connect.transforms.predicates.Predicate;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.mockito.junit.MockitoJUnitRunner;
+
+import org.junit.jupiter.api.Test;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 
 import static java.util.Collections.singletonMap;
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.StrictStubs.class)
+@MockitoSettings(strictness = Strictness.STRICT_STUBS)
 public class TransformationStageTest {
 
     private final SourceRecord initial = new SourceRecord(singletonMap("initial", 1), null, null, null, null);
@@ -52,7 +53,9 @@ public class TransformationStageTest {
         when(predicate.test(any())).thenReturn(predicateResult);
         @SuppressWarnings("unchecked")
         Transformation<SourceRecord> transformation = mock(Transformation.class);
-        when(transformation.apply(any())).thenReturn(transformed);
+        if (expectedResult == transformed) {
+            when(transformation.apply(any())).thenReturn(transformed);
+        }
         TransformationStage<SourceRecord> stage = new TransformationStage<>(
                 predicate,
                 negate,
