@@ -28,30 +28,26 @@ import org.apache.kafka.connect.source.SourceConnectorContext;
 import org.apache.kafka.connect.storage.CloseableOffsetStorageReader;
 import org.apache.kafka.connect.storage.ConnectorOffsetBackingStore;
 import org.apache.kafka.connect.util.Callback;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
 
-
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.Map;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.EnumSource;
 import org.mockito.ArgumentCaptor;
 import org.mockito.InOrder;
 import org.mockito.Mock;
-import org.mockito.junit.MockitoJUnit;
-import org.mockito.junit.MockitoRule;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import java.util.HashMap;
+import java.util.Map;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.ArgumentMatchers.isNull;
@@ -63,12 +59,14 @@ import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.verifyNoMoreInteractions;
 import static org.mockito.Mockito.when;
 
-@RunWith(Parameterized.class)
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.STRICT_STUBS)
 public class WorkerConnectorTest {
 
     private static final String VERSION = "1.1";
     public static final String CONNECTOR = "connector";
     public static final Map<String, String> CONFIG = new HashMap<>();
+
     static {
         CONFIG.put(ConnectorConfig.CONNECTOR_CLASS_CONFIG, TestConnector.class.getName());
         CONFIG.put(ConnectorConfig.NAME_CONFIG, CONNECTOR);
@@ -77,25 +75,18 @@ public class WorkerConnectorTest {
     public ConnectorConfig connectorConfig;
     public MockConnectMetrics metrics;
 
-    @Rule
-    public MockitoRule rule = MockitoJUnit.rule().strictness(Strictness.STRICT_STUBS);
 
     @Mock private Plugins plugins;
     @Mock private CloseableConnectorContext ctx;
     @Mock private ConnectorStatus.Listener listener;
     @Mock private ClassLoader classLoader;
 
-    private final ConnectorType connectorType;
-    private final Connector connector;
-    private final CloseableOffsetStorageReader offsetStorageReader;
-    private final ConnectorOffsetBackingStore offsetStore;
+    private ConnectorType connectorType;
+    private Connector connector;
+    private CloseableOffsetStorageReader offsetStorageReader;
+    private ConnectorOffsetBackingStore offsetStore;
 
-    @Parameterized.Parameters
-    public static Collection<ConnectorType> parameters() {
-        return Arrays.asList(ConnectorType.SOURCE, ConnectorType.SINK);
-    }
-
-    public WorkerConnectorTest(ConnectorType connectorType) {
+    private void setConnector(ConnectorType connectorType) {
         this.connectorType = connectorType;
         switch (connectorType) {
             case SINK:
@@ -112,20 +103,22 @@ public class WorkerConnectorTest {
                 throw new IllegalStateException("Unexpected connector type: " + connectorType);
         }
     }
-
-    @Before
-    public void setup() {
+    
+    public void setup(ConnectorType connectorType) {
+        setConnector(connectorType);
         connectorConfig = new ConnectorConfig(plugins, CONFIG);
         metrics = new MockConnectMetrics();
     }
 
-    @After
+    @AfterEach
     public void tearDown() {
         if (metrics != null) metrics.stop();
     }
 
-    @Test
-    public void testInitializeFailure() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testInitializeFailure(ConnectorType connectorType) {
+        setup(connectorType);
         RuntimeException exception = new RuntimeException();
 
         when(connector.version()).thenReturn(VERSION);
@@ -144,8 +137,10 @@ public class WorkerConnectorTest {
         verifyCleanShutdown(false);
     }
 
-    @Test
-    public void testFailureIsFinalState() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testFailureIsFinalState(ConnectorType connectorType) {
+        setup(connectorType);
         RuntimeException exception = new RuntimeException();
 
         when(connector.version()).thenReturn(VERSION);
@@ -171,8 +166,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupAndShutdown() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupAndShutdown(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -195,8 +192,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupAndPause() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupAndPause(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -224,8 +223,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupAndStop() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupAndStop(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -254,8 +255,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testOnResume() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testOnResume(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -284,8 +287,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupPaused() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupPaused(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -308,8 +313,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupStopped() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupStopped(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -332,8 +339,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStartupFailure() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStartupFailure(ConnectorType connectorType) {
+        setup(connectorType);
         RuntimeException exception = new RuntimeException();
 
         when(connector.version()).thenReturn(VERSION);
@@ -359,8 +368,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testStopFailure() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testStopFailure(ConnectorType connectorType) {
+        setup(connectorType);
         RuntimeException exception = new RuntimeException();
 
         when(connector.version()).thenReturn(VERSION);
@@ -401,8 +412,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(listener);
     }
 
-    @Test
-    public void testShutdownFailure() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testShutdownFailure(ConnectorType connectorType) {
+        setup(connectorType);
         RuntimeException exception = new RuntimeException();
 
         when(connector.version()).thenReturn(VERSION);
@@ -429,8 +442,10 @@ public class WorkerConnectorTest {
         verifyShutdown(false, true);
     }
 
-    @Test
-    public void testTransitionStartedToStarted() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testTransitionStartedToStarted(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -456,8 +471,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testTransitionPausedToPaused() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testTransitionPausedToPaused(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -487,8 +504,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testTransitionStoppedToStopped() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testTransitionStoppedToStopped(ConnectorType connectorType) {
+        setup(connectorType);
         when(connector.version()).thenReturn(VERSION);
 
         Callback<TargetState> onStateChange = mockCallback();
@@ -518,8 +537,10 @@ public class WorkerConnectorTest {
         verifyNoMoreInteractions(onStateChange);
     }
 
-    @Test
-    public void testFailConnectorThatIsNeitherSourceNorSink() {
+    @ParameterizedTest
+    @EnumSource(value = ConnectorType.class, names = {"SOURCE", "SINK"})
+    public void testFailConnectorThatIsNeitherSourceNorSink(ConnectorType connectorType) {
+        setup(connectorType);
         Connector badConnector = mock(Connector.class);
         when(badConnector.version()).thenReturn(VERSION);
         WorkerConnector workerConnector = new WorkerConnector(CONNECTOR, badConnector, connectorConfig, ctx, metrics, listener, offsetStorageReader, offsetStore, classLoader);
@@ -642,6 +663,6 @@ public class WorkerConnectorTest {
         }
     }
 
-    private static abstract class TestConnector extends Connector {
+    private abstract static class TestConnector extends Connector {
     }
 }
