@@ -41,15 +41,15 @@ import org.apache.kafka.connect.storage.AppliedConnectorConfig;
 import org.apache.kafka.connect.storage.ClusterConfigState;
 import org.apache.kafka.connect.storage.KafkaConfigBackingStore;
 import org.apache.kafka.connect.util.ConnectorTaskId;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 import org.mockito.Mock;
-import org.mockito.junit.MockitoJUnit;
-import org.mockito.junit.MockitoRule;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
 
 import java.nio.ByteBuffer;
@@ -63,26 +63,23 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import static org.apache.kafka.connect.runtime.distributed.ConnectProtocolCompatibility.COMPATIBLE;
 import static org.apache.kafka.connect.runtime.distributed.ConnectProtocolCompatibility.EAGER;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.assertThrows;
-import static org.junit.runners.Parameterized.Parameter;
-import static org.junit.runners.Parameterized.Parameters;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(value = Parameterized.class)
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.STRICT_STUBS)
 public class WorkerCoordinatorTest {
 
-    @Rule
-    public MockitoRule rule = MockitoJUnit.rule().strictness(Strictness.STRICT_STUBS);
-
     private static final String LEADER_URL = "leaderUrl:8083";
     private static final String MEMBER_URL = "memberUrl:8083";
 
@@ -118,21 +115,14 @@ public class WorkerCoordinatorTest {
     // Arguments are:
     // - Protocol type
     // - Expected metadata size
-    @Parameters
-    public static Iterable<?> mode() {
-        return Arrays.asList(new Object[][]{
-                {EAGER, 1},
-                {COMPATIBLE, 2}});
+    static Stream<Arguments> mode() {
+        return Stream.of(
+            Arguments.of(EAGER, 1),
+            Arguments.of(COMPATIBLE, 2)
+        );
     }
 
-    @Parameter
-    public ConnectProtocolCompatibility compatibility;
-
-    @Parameter(1)
-    public int expectedMetadataSize;
-
-    @Before
-    public void setup() {
+    public void setup(ConnectProtocolCompatibility compatibility) {
         LogContext logContext = new LogContext();
 
         this.time = new MockTime();
@@ -241,7 +231,7 @@ public class WorkerCoordinatorTest {
         );
     }
 
-    @After
+    @AfterEach
     public void teardown() {
         this.metrics.close();
     }
@@ -249,8 +239,10 @@ public class WorkerCoordinatorTest {
     // We only test functionality unique to WorkerCoordinator. Most functionality is already well tested via the tests
     // that cover AbstractCoordinator & ConsumerCoordinator.
 
-    @Test
-    public void testMetadata() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testMetadata(ConnectProtocolCompatibility compatibility, int expectedMetadataSize) {
+        setup(compatibility);
         when(configStorage.snapshot()).thenReturn(configState1);
 
         JoinGroupRequestData.JoinGroupRequestProtocolCollection serialized = coordinator.metadata();
@@ -267,8 +259,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testNormalJoinGroupLeader() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testNormalJoinGroupLeader(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         when(configStorage.snapshot()).thenReturn(configState1);
 
         final String memberId = "leader";
@@ -302,8 +296,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testNormalJoinGroupFollower() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testNormalJoinGroupFollower(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         when(configStorage.snapshot()).thenReturn(configState1);
 
         final String memberId = "member";
@@ -333,8 +329,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testJoinLeaderCannotAssign() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testJoinLeaderCannotAssign(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         // If the selected leader can't get up to the maximum offset, it will fail to assign and we should immediately
         // need to retry the join.
         when(configStorage.snapshot()).thenReturn(configState1);
@@ -366,8 +364,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage, times(2)).snapshot();
     }
 
-    @Test
-    public void testRejoinGroup() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testRejoinGroup(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         when(configStorage.snapshot()).thenReturn(configState1);
 
         client.prepareResponse(FindCoordinatorResponse.prepareResponse(Errors.NONE, groupId, node));
@@ -405,8 +405,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage, times(2)).snapshot();
     }
 
-    @Test
-    public void testLeaderPerformAssignment1() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testLeaderPerformAssignment1(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         // Since all the protocol responses are mocked, the other tests validate doSync runs, but don't validate its
         // output. So we test it directly here.
 
@@ -445,8 +447,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testLeaderPerformAssignment2() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testLeaderPerformAssignment2(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         // Since all the protocol responses are mocked, the other tests validate doSync runs, but don't validate its
         // output. So we test it directly here.
 
@@ -486,8 +490,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testLeaderPerformAssignmentSingleTaskConnectors() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testLeaderPerformAssignmentSingleTaskConnectors(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         // Since all the protocol responses are mocked, the other tests validate doSync runs, but don't validate its
         // output. So we test it directly here.
 
@@ -528,8 +534,10 @@ public class WorkerCoordinatorTest {
         verify(configStorage).snapshot();
     }
 
-    @Test
-    public void testSkippingAssignmentFails() {
+    @ParameterizedTest
+    @MethodSource("mode")
+    public void testSkippingAssignmentFails(ConnectProtocolCompatibility compatibility) {
+        setup(compatibility);
         // Connect does not support static membership so skipping assignment should
         // never be set to true by the group coordinator. It is treated as an
         // illegal state if it would.
