@@ -16,8 +16,16 @@
  */
 package org.apache.kafka.connect.runtime.rest;
 
+import org.apache.kafka.common.config.AbstractConfig;
+import org.apache.kafka.common.utils.LogCaptureAppender;
+import org.apache.kafka.connect.rest.ConnectRestExtension;
+import org.apache.kafka.connect.runtime.Herder;
+import org.apache.kafka.connect.runtime.isolation.Plugins;
+import org.apache.kafka.connect.runtime.rest.entities.LoggerLevel;
+
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
+
 import org.apache.http.HttpHost;
 import org.apache.http.HttpRequest;
 import org.apache.http.HttpResponse;
@@ -29,22 +37,16 @@ import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.BasicResponseHandler;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClients;
-import org.apache.kafka.common.config.AbstractConfig;
-import org.apache.kafka.common.utils.LogCaptureAppender;
-import org.apache.kafka.connect.rest.ConnectRestExtension;
-import org.apache.kafka.connect.runtime.Herder;
-import org.apache.kafka.connect.runtime.isolation.Plugins;
-import org.apache.kafka.connect.runtime.rest.entities.LoggerLevel;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.Mock;
-import org.mockito.junit.MockitoJUnitRunner;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.slf4j.LoggerFactory;
 
-import javax.ws.rs.core.MediaType;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.net.URI;
@@ -56,15 +58,19 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import javax.ws.rs.core.MediaType;
+
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doReturn;
 
-@RunWith(MockitoJUnitRunner.StrictStubs.class)
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.STRICT_STUBS)
 public class ConnectRestServerTest {
 
     @Mock private RestClient restClient;
@@ -76,12 +82,12 @@ public class ConnectRestServerTest {
 
     protected static final String KAFKA_CLUSTER_ID = "Xbafgnagvar";
 
-    @Before
+    @BeforeEach
     public void setUp() {
         httpClient = HttpClients.createMinimal();
     }
 
-    @After
+    @AfterEach
     public void tearDown() throws IOException {
         for (CloseableHttpResponse response: responses) {
             response.close();
@@ -117,7 +123,7 @@ public class ConnectRestServerTest {
         configMap.put(RestServerConfig.LISTENERS_CONFIG, "http://localhost:8080,https://localhost:8443");
 
         server = new ConnectRestServer(null, restClient, configMap);
-        Assert.assertEquals("http://localhost:8080/", server.advertisedUrl().toString());
+        assertEquals("http://localhost:8080/", server.advertisedUrl().toString());
         server.stop();
 
         // Advertised URI from listeners with protocol
@@ -126,7 +132,7 @@ public class ConnectRestServerTest {
         configMap.put(RestServerConfig.REST_ADVERTISED_LISTENER_CONFIG, "https");
 
         server = new ConnectRestServer(null, restClient, configMap);
-        Assert.assertEquals("https://localhost:8443/", server.advertisedUrl().toString());
+        assertEquals("https://localhost:8443/", server.advertisedUrl().toString());
         server.stop();
 
         // Advertised URI from listeners with only SSL available
@@ -134,7 +140,7 @@ public class ConnectRestServerTest {
         configMap.put(RestServerConfig.LISTENERS_CONFIG, "https://localhost:8443");
 
         server = new ConnectRestServer(null, restClient, configMap);
-        Assert.assertEquals("https://localhost:8443/", server.advertisedUrl().toString());
+        assertEquals("https://localhost:8443/", server.advertisedUrl().toString());
         server.stop();
 
         // Listener is overridden by advertised values
@@ -145,7 +151,7 @@ public class ConnectRestServerTest {
         configMap.put(RestServerConfig.REST_ADVERTISED_PORT_CONFIG, "10000");
 
         server = new ConnectRestServer(null, restClient, configMap);
-        Assert.assertEquals("http://somehost:10000/", server.advertisedUrl().toString());
+        assertEquals("http://somehost:10000/", server.advertisedUrl().toString());
         server.stop();
 
         // correct listener is chosen when https listener is configured before http listener and advertised listener is http
@@ -154,7 +160,7 @@ public class ConnectRestServerTest {
         configMap.put(RestServerConfig.REST_ADVERTISED_LISTENER_CONFIG, "http");
 
         server = new ConnectRestServer(null, restClient, configMap);
-        Assert.assertEquals("http://plaintext-localhost:4761/", server.advertisedUrl().toString());
+        assertEquals("http://plaintext-localhost:4761/", server.advertisedUrl().toString());
         server.stop();
     }
 
@@ -173,10 +179,10 @@ public class ConnectRestServerTest {
         HttpOptions request = new HttpOptions("/connectors");
         request.addHeader("Content-Type", MediaType.WILDCARD);
         HttpResponse response = executeRequest(server.advertisedUrl(), request);
-        Assert.assertEquals(MediaType.TEXT_PLAIN, response.getEntity().getContentType().getValue());
+        assertEquals(MediaType.TEXT_PLAIN, response.getEntity().getContentType().getValue());
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         response.getEntity().writeTo(baos);
-        Assert.assertArrayEquals(
+        assertArrayEquals(
             request.getAllowedMethods(response).toArray(),
             new String(baos.toByteArray(), StandardCharsets.UTF_8).split(", ")
         );
@@ -203,10 +209,10 @@ public class ConnectRestServerTest {
         request.addHeader("Origin", origin);
         HttpResponse response = executeRequest(serverUrl, request);
 
-        Assert.assertEquals(200, response.getStatusLine().getStatusCode());
+        assertEquals(200, response.getStatusLine().getStatusCode());
 
         if (expectedHeader != null) {
-            Assert.assertEquals(expectedHeader,
+            assertEquals(expectedHeader,
                 response.getFirstHeader("Access-Control-Allow-Origin").getValue());
         }
 
@@ -215,13 +221,13 @@ public class ConnectRestServerTest {
         request.addHeader("Origin", origin);
         request.addHeader("Access-Control-Request-Method", method);
         response = executeRequest(serverUrl, request);
-        Assert.assertEquals(404, response.getStatusLine().getStatusCode());
+        assertEquals(404, response.getStatusLine().getStatusCode());
         if (expectedHeader != null) {
-            Assert.assertEquals(expectedHeader,
+            assertEquals(expectedHeader,
                 response.getFirstHeader("Access-Control-Allow-Origin").getValue());
         }
         if (method != null) {
-            Assert.assertEquals(method,
+            assertEquals(method,
                 response.getFirstHeader("Access-Control-Allow-Methods").getValue());
         }
     }
@@ -242,7 +248,7 @@ public class ConnectRestServerTest {
         HttpRequest request = new HttpGet("/connectors");
         HttpResponse response = executeRequest(server.advertisedUrl(), request);
 
-        Assert.assertEquals(200, response.getStatusLine().getStatusCode());
+        assertEquals(200, response.getStatusLine().getStatusCode());
     }
 
     @Test
@@ -304,7 +310,7 @@ public class ConnectRestServerTest {
 
         HttpRequest request = new HttpGet("/admin/loggers");
         HttpResponse response = executeRequest(server.advertisedUrl(), request);
-        Assert.assertEquals(404, response.getStatusLine().getStatusCode());
+        assertEquals(404, response.getStatusLine().getStatusCode());
     }
 
     @Test
@@ -324,7 +330,7 @@ public class ConnectRestServerTest {
 
         HttpRequest request = new HttpGet("/admin/loggers");
         HttpResponse response = executeRequest(server.advertisedUrl(), request);
-        Assert.assertEquals(404, response.getStatusLine().getStatusCode());
+        assertEquals(404, response.getStatusLine().getStatusCode());
     }
 
     @Test
@@ -386,12 +392,12 @@ public class ConnectRestServerTest {
         server.initializeResources(herder);
         HttpRequest request = new HttpGet("/connectors");
         HttpResponse response = executeRequest(server.advertisedUrl(), request);
-        Assert.assertEquals(200, response.getStatusLine().getStatusCode());
+        assertEquals(200, response.getStatusLine().getStatusCode());
         if (!headerConfig.isEmpty()) {
             expectedHeaders.forEach((k, v) ->
-                    Assert.assertEquals(response.getFirstHeader(k).getValue(), v));
+                    assertEquals(response.getFirstHeader(k).getValue(), v));
         } else {
-            Assert.assertNull(response.getFirstHeader("X-Frame-Options"));
+            assertNull(response.getFirstHeader("X-Frame-Options"));
         }
     }
 
@@ -399,7 +405,7 @@ public class ConnectRestServerTest {
         HttpRequest request = new HttpGet(endpoint);
         HttpResponse response = executeRequest(serverUrl, request);
 
-        Assert.assertEquals(200, response.getStatusLine().getStatusCode());
+        assertEquals(200, response.getStatusLine().getStatusCode());
         return new BasicResponseHandler().handleResponse(response);
     }
 
@@ -410,7 +416,7 @@ public class ConnectRestServerTest {
         request.setEntity(entity);
         HttpResponse response = executeRequest(serverUrl, request);
 
-        Assert.assertEquals(200, response.getStatusLine().getStatusCode());
+        assertEquals(200, response.getStatusLine().getStatusCode());
         return new BasicResponseHandler().handleResponse(response);
     }
 
