@@ -17,8 +17,7 @@
 
 package kafka.zk
 
-import org.apache.zookeeper.server.ZooKeeperServer
-import org.apache.zookeeper.server.NIOServerCnxnFactory
+import org.apache.zookeeper.server.{NIOServerCnxnFactory, SessionTrackerImpl, ZooKeeperServer}
 import kafka.utils.{CoreUtils, Logging, TestUtils}
 
 import java.net.InetSocketAddress
@@ -54,6 +53,14 @@ class EmbeddedZookeeper extends Closeable with Logging {
     // Also shuts down ZooKeeperServer
     CoreUtils.swallow(factory.shutdown(), this)
 
+    zookeeper.getSessionTracker match {
+      case tracker: SessionTrackerImpl =>
+        while (tracker.isAlive) {
+          Thread.sleep(100)
+        }
+      case _ =>
+    }
+
     def isDown(): Boolean = {
       try {
         ZkFourLetterWords.sendStat("127.0.0.1", port, 3000)
