@@ -16,9 +16,9 @@
  */
 package org.apache.kafka.metadata.migration;
 
-import org.apache.kafka.common.config.ConfigResource;
 import org.apache.kafka.common.TopicIdPartition;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.config.ConfigResource;
 import org.apache.kafka.image.AclsImage;
 import org.apache.kafka.image.AclsImageTest;
 import org.apache.kafka.image.ClientQuotasImage;
@@ -33,6 +33,7 @@ import org.apache.kafka.image.ProducerIdsImage;
 import org.apache.kafka.image.ProducerIdsImageTest;
 import org.apache.kafka.image.ScramImage;
 import org.apache.kafka.image.TopicsImageTest;
+
 import org.junit.jupiter.api.Test;
 
 import java.util.Arrays;
@@ -62,18 +63,17 @@ public class KRaftMigrationZkWriterTest {
                 visitor.visitTopic("foo", TopicsImageTest.FOO_UUID, assignments);
 
                 // Skip partition 1, visit 3 (the extra one)
-                IntStream.of(0, 2, 3).forEach(partitionId -> {
+                IntStream.of(0, 2, 3).forEach(partitionId ->
                     visitor.visitPartition(
                         new TopicIdPartition(TopicsImageTest.FOO_UUID, new TopicPartition("foo", partitionId)),
                         TopicsImageTest.IMAGE1.getPartition(TopicsImageTest.FOO_UUID, partitionId)
-                    );
-                });
+                    )
+                );
 
             }
         };
 
         CapturingConfigMigrationClient configClient = new CapturingConfigMigrationClient();
-        CapturingAclMigrationClient aclClient = new CapturingAclMigrationClient();
         CapturingMigrationClient migrationClient = CapturingMigrationClient.newBuilder()
             .setBrokersInZk(0)
             .setTopicMigrationClient(topicClient)
@@ -95,9 +95,9 @@ public class KRaftMigrationZkWriterTest {
             DelegationTokenImage.EMPTY
         );
 
-        writer.handleSnapshot(image, (opType, opLog, operation) -> {
-            operation.apply(ZkMigrationLeadershipState.EMPTY);
-        });
+        writer.handleSnapshot(image, (opType, opLog, operation) ->
+            operation.apply(ZkMigrationLeadershipState.EMPTY)
+        );
         assertEquals(topicClient.updatedTopics.get("foo").size(), 3);
         assertEquals(topicClient.deletedTopicPartitions.get("foo"), Collections.singleton(3));
         assertEquals(topicClient.updatedTopicPartitions.get("foo"), Collections.singleton(1));
