@@ -19,29 +19,29 @@ package org.apache.kafka.raft.internals;
 import org.apache.kafka.common.compress.Compression;
 import org.apache.kafka.common.errors.RecordBatchTooLargeException;
 import org.apache.kafka.common.memory.MemoryPool;
+import org.apache.kafka.common.message.LeaderChangeMessage;
+import org.apache.kafka.common.message.SnapshotFooterRecord;
+import org.apache.kafka.common.message.SnapshotHeaderRecord;
+import org.apache.kafka.common.message.VotersRecord;
 import org.apache.kafka.common.protocol.ObjectSerializationCache;
 import org.apache.kafka.common.record.MemoryRecords;
 import org.apache.kafka.common.record.MutableRecordBatch;
 import org.apache.kafka.common.utils.Time;
 import org.apache.kafka.raft.errors.BufferAllocationException;
 import org.apache.kafka.raft.errors.NotLeaderException;
-import org.apache.kafka.raft.errors.UnexpectedBaseOffsetException;
 import org.apache.kafka.server.common.serialization.RecordSerde;
 
-import org.apache.kafka.common.message.LeaderChangeMessage;
-import org.apache.kafka.common.message.SnapshotHeaderRecord;
-import org.apache.kafka.common.message.SnapshotFooterRecord;
 import java.io.Closeable;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.OptionalInt;
 import java.util.OptionalLong;
-import java.util.Iterator;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.locks.ReentrantLock;
@@ -49,23 +49,30 @@ import java.util.concurrent.locks.ReentrantLock;
 public class BatchAccumulator<T> implements Closeable {
     @FunctionalInterface
     public interface MemoryRecordsCreator {
-        MemoryRecords create(long baseOffset, int epoch, ByteBuffer byteBuffer);
+        MemoryRecords create(
+            long baseOffset,
+            int epoch,
+            Compression compression,
+            ByteBuffer byteBuffer
+        );
     }
 
     private final int epoch;
     private final Time time;
-    private final SimpleTimer lingerTimer;
     private final int lingerMs;
     private final int maxBatchSize;
+    private final int maxNumberOfBatches;
     private final Compression compression;
     private final MemoryPool memoryPool;
-    private final ReentrantLock appendLock;
     private final RecordSerde<T> serde;
 
-    private final ConcurrentLinkedQueue<CompletedBatch<T>> completed;
-    private volatile DrainStatus drainStatus;
+    private final SimpleTimer lingerTimer = new SimpleTimer();
+    private final AtomicLong drainOffset = new AtomicLong(Long.MAX_VALUE);
+    private final ConcurrentLinkedQueue<CompletedBatch<T>> completed = new ConcurrentLinkedQueue<>();
+    private volatile DrainStatus drainStatus = DrainStatus.NONE;
 
     // These fields are protected by the append lock
+    private final ReentrantLock appendLock = new ReentrantLock();
     private long nextOffset;
     private BatchBuilder<T> currentBatch;
 
@@ -78,6 +85,7 @@ public class BatchAccumulator<T> implements Closeable {
         long baseOffset,
         int lingerMs,
         int maxBatchSize,
+        int maxNumberOfBatches,
         MemoryPool memoryPool,
         Time time,
         Compression compression,
@@ -86,46 +94,45 @@ public class BatchAccumulator<T> implements Closeable {
         this.epoch = epoch;
         this.lingerMs = lingerMs;
         this.maxBatchSize = maxBatchSize;
+        this.maxNumberOfBatches = maxNumberOfBatches;
         this.memoryPool = memoryPool;
         this.time = time;
-        this.lingerTimer = new SimpleTimer();
         this.compression = compression;
         this.serde = serde;
         this.nextOffset = baseOffset;
-        this.drainStatus = DrainStatus.NONE;
-        this.completed = new ConcurrentLinkedQueue<>();
-        this.appendLock = new ReentrantLock();
     }
 
     /**
      * Append to the accumulator.
      *
-     * @param epoch                             The leader epoch to append at.
-     * @param records                           The records to append.
-     * @param requiredBaseOffset                If this is non-empty, the base offset which we must use.
-     * @param isAtomic                          True if we should append the records as a single batch.
-     * @return                                  The end offset.
+     * @param epoch the leader epoch to append at
+     * @param records the records to append
+     * @param delayDrain whether the records could be drained
+     * @return the offset of the last record
      *
-     * @throws NotLeaderException               Indicates that an append operation cannot be completed
-     *                                          because the provided leader epoch was too old.
-     * @throws IllegalArgumentException         Indicates that an append operation cannot be completed
-     *                                          because the provided leader epoch was too new.
-     * @throws UnexpectedBaseOffsetException    Indicates that an append operation cannot
-     *                                          be completed because it would have resulted
-     *                                          in an unexpected base offset.
+     * @throws NotLeaderException indicates that an append operation cannot be completed because the
+     *         provided leader epoch was too old
+     * @throws IllegalArgumentException indicates that an append operation cannot be completed
+     *         because the provided leader epoch was too new
+     * @throws IllegalStateException if the number of accumulated batches reaches the maximum
+     *         number of batches
      */
-    public long append(
-        int epoch,
-        List<T> records,
-        OptionalLong requiredBaseOffset,
-        boolean isAtomic
-    ) {
+    public long append(int epoch, List<T> records, boolean delayDrain) {
+        int numberOfCompletedBatches = completed.size();
         if (epoch < this.epoch) {
             throw new NotLeaderException("Append failed because the given epoch " + epoch + " is stale. " +
                     "Current leader epoch = " + this.epoch());
         } else if (epoch > this.epoch) {
             throw new IllegalArgumentException("Attempt to append from epoch " + epoch +
                 " which is larger than the current epoch " + this.epoch);
+        } else if (numberOfCompletedBatches >= maxNumberOfBatches) {
+            throw new IllegalStateException(
+                String.format(
+                    "Attempting to append records when the number of batches %s reached %s",
+                    numberOfCompletedBatches,
+                    maxNumberOfBatches
+                )
+            );
         }
 
         ObjectSerializationCache serializationCache = new ObjectSerializationCache();
@@ -133,28 +140,22 @@ public class BatchAccumulator<T> implements Closeable {
         appendLock.lock();
         try {
             long lastOffset = nextOffset + records.size() - 1;
-            requiredBaseOffset.ifPresent(r -> {
-                if (r != nextOffset) {
-                    throw new UnexpectedBaseOffsetException("Wanted base offset " + r +
-                            ", but the next offset was " + nextOffset);
-                }
-            });
             maybeCompleteDrain();
 
             BatchBuilder<T> batch = null;
-            if (isAtomic) {
-                batch = maybeAllocateBatch(records, serializationCache);
+            batch = maybeAllocateBatch(records, serializationCache);
+            if (batch == null) {
+                throw new BufferAllocationException("Append failed because we failed to allocate memory to write the batch");
+            }
+
+            if (delayDrain) {
+                // The user asked to not drain these records. If the drainOffset is not already set,
+                // then set the record at the current end offset (nextOffset) as maximum offset
+                // that can be drained.
+                drainOffset.compareAndSet(Long.MAX_VALUE, nextOffset);
             }
 
             for (T record : records) {
-                if (!isAtomic) {
-                    batch = maybeAllocateBatch(Collections.singleton(record), serializationCache);
-                }
-
-                if (batch == null) {
-                    throw new BufferAllocationException("Append failed because we failed to allocate memory to write the batch");
-                }
-
                 batch.appendRecord(record, serializationCache);
             }
 
@@ -212,6 +213,13 @@ public class BatchAccumulator<T> implements Closeable {
         currentBatch = null;
     }
 
+    /**
+     * Allows draining of all batches.
+     */
+    public void allowDrain() {
+        drainOffset.set(Long.MAX_VALUE);
+    }
+
     /**
      * Append a control batch from a supplied memory record.
      *
@@ -220,15 +228,21 @@ public class BatchAccumulator<T> implements Closeable {
      * @param valueCreator a function that uses the passed buffer to create the control
      *        batch that will be appended. The memory records returned must contain one
      *        control batch and that control batch have at least one record.
+     * @return the last of offset of the records created
      */
-    public void appendControlMessages(MemoryRecordsCreator valueCreator) {
+    public long appendControlMessages(MemoryRecordsCreator valueCreator) {
         appendLock.lock();
         try {
             ByteBuffer buffer = memoryPool.tryAllocate(maxBatchSize);
             if (buffer != null) {
                 try {
                     forceDrain();
-                    MemoryRecords memoryRecords = valueCreator.create(nextOffset, epoch, buffer);
+                    MemoryRecords memoryRecords = valueCreator.create(
+                        nextOffset,
+                        epoch,
+                        compression,
+                        buffer
+                    );
 
                     int numberOfRecords = validateMemoryRecordsAndReturnCount(memoryRecords);
 
@@ -250,6 +264,8 @@ public class BatchAccumulator<T> implements Closeable {
             } else {
                 throw new IllegalStateException("Could not allocate buffer for the control record");
             }
+
+            return nextOffset - 1;
         } finally {
             appendLock.unlock();
         }
@@ -293,6 +309,30 @@ public class BatchAccumulator<T> implements Closeable {
         return numberOfRecords;
     }
 
+    /**
+     * Append a {@link VotersRecord} record to the batch
+     *
+     * @param voters the record to append
+     * @param currentTimestamp the current time in milliseconds
+     * @return the last of offset of the records created
+     * @throws IllegalStateException on failure to allocate a buffer for the record
+     */
+    public long appendVotersRecord(
+        VotersRecord voters,
+        long currentTimestamp
+    ) {
+        return appendControlMessages((baseOffset, epoch, compression, buffer) ->
+            MemoryRecords.withVotersRecord(
+                baseOffset,
+                currentTimestamp,
+                epoch,
+                buffer,
+                voters
+            )
+        );
+    }
+
+
     /**
      * Append a {@link LeaderChangeMessage} record to the batch
      *
@@ -304,7 +344,7 @@ public class BatchAccumulator<T> implements Closeable {
         LeaderChangeMessage leaderChangeMessage,
         long currentTimestamp
     ) {
-        appendControlMessages((baseOffset, epoch, buffer) ->
+        appendControlMessages((baseOffset, epoch, compression, buffer) ->
             MemoryRecords.withLeaderChangeMessage(
                 baseOffset,
                 currentTimestamp,
@@ -327,7 +367,7 @@ public class BatchAccumulator<T> implements Closeable {
         SnapshotHeaderRecord snapshotHeaderRecord,
         long currentTimestamp
     ) {
-        appendControlMessages((baseOffset, epoch, buffer) ->
+        appendControlMessages((baseOffset, epoch, compression, buffer) ->
             MemoryRecords.withSnapshotHeaderRecord(
                 baseOffset,
                 currentTimestamp,
@@ -349,7 +389,7 @@ public class BatchAccumulator<T> implements Closeable {
         SnapshotFooterRecord snapshotFooterRecord,
         long currentTimestamp
     ) {
-        appendControlMessages((baseOffset, epoch, buffer) ->
+        appendControlMessages((baseOffset, epoch, compression, buffer) ->
             MemoryRecords.withSnapshotFooterRecord(
                 baseOffset,
                 currentTimestamp,
@@ -391,7 +431,6 @@ public class BatchAccumulator<T> implements Closeable {
                 compression,
                 nextOffset,
                 time.milliseconds(),
-                false,
                 epoch,
                 maxBatchSize
             );
@@ -416,7 +455,10 @@ public class BatchAccumulator<T> implements Closeable {
      * @return the delay in milliseconds before the next expected drain
      */
     public long timeUntilDrain(long currentTimeMs) {
-        if (drainStatus == DrainStatus.FINISHED) {
+        boolean drainableBatches = Optional.ofNullable(completed.peek())
+            .map(batch -> batch.drainable(drainOffset.get()))
+            .orElse(false);
+        if (drainableBatches) {
             return 0;
         } else {
             return lingerTimer.remainingMs(currentTimeMs);
@@ -451,6 +493,10 @@ public class BatchAccumulator<T> implements Closeable {
      * @return the list of completed batches
      */
     public List<CompletedBatch<T>> drain() {
+        return drain(drainOffset.get());
+    }
+
+    private List<CompletedBatch<T>> drain(long drainOffset) {
         // Start the drain if it has not been started already
         if (drainStatus == DrainStatus.NONE) {
             drainStatus = DrainStatus.STARTED;
@@ -468,19 +514,21 @@ public class BatchAccumulator<T> implements Closeable {
         // If the drain has finished, then all of the batches will be completed
         if (drainStatus == DrainStatus.FINISHED) {
             drainStatus = DrainStatus.NONE;
-            return drainCompleted();
+            return drainCompleted(drainOffset);
         } else {
             return Collections.emptyList();
         }
     }
 
-    private List<CompletedBatch<T>> drainCompleted() {
-        List<CompletedBatch<T>> res = new ArrayList<>(completed.size());
+    private List<CompletedBatch<T>> drainCompleted(long drainOffset) {
+        List<CompletedBatch<T>> res = new ArrayList<>();
         while (true) {
-            CompletedBatch<T> batch = completed.poll();
-            if (batch == null) {
+            CompletedBatch<T> batch = completed.peek();
+            if (batch == null || !batch.drainable(drainOffset)) {
                 return res;
             } else {
+                // The batch can be drained so remove the batch and add it to the result.
+                completed.poll();
                 res.add(batch);
             }
         }
@@ -493,17 +541,16 @@ public class BatchAccumulator<T> implements Closeable {
         return !lingerTimer.isRunning();
     }
 
-    /**
-     * Get the number of completed batches which are ready to be drained.
-     * This does not include the batch that is currently being filled.
-     */
-    public int numCompletedBatches() {
-        return completed.size();
-    }
-
     @Override
     public void close() {
-        List<CompletedBatch<T>> unwritten = drain();
+        // Acquire the lock so that drain is guaranteed to complete the current batch
+        appendLock.lock();
+        List<CompletedBatch<T>> unwritten;
+        try {
+            unwritten = drain(Long.MAX_VALUE);
+        } finally {
+            appendLock.unlock();
+        }
         unwritten.forEach(CompletedBatch::release);
     }
 
@@ -524,14 +571,14 @@ public class BatchAccumulator<T> implements Closeable {
             MemoryPool pool,
             ByteBuffer initialBuffer
         ) {
-            Objects.requireNonNull(data.firstBatch(), "Expected memory records to contain one batch");
-
             this.baseOffset = baseOffset;
             this.records = Optional.of(records);
             this.numRecords = records.size();
             this.data = data;
             this.pool = pool;
             this.initialBuffer = initialBuffer;
+
+            validateContruction();
         }
 
         private CompletedBatch(
@@ -541,14 +588,24 @@ public class BatchAccumulator<T> implements Closeable {
             MemoryPool pool,
             ByteBuffer initialBuffer
         ) {
-            Objects.requireNonNull(data.firstBatch(), "Expected memory records to contain one batch");
-
             this.baseOffset = baseOffset;
             this.records = Optional.empty();
             this.numRecords = numRecords;
             this.data = data;
             this.pool = pool;
             this.initialBuffer = initialBuffer;
+
+            validateContruction();
+        }
+
+        private void validateContruction() {
+            Objects.requireNonNull(data.firstBatch(), "Expected memory records to contain one batch");
+
+            if (numRecords <= 0) {
+                throw new IllegalArgumentException(
+                    String.format("Completed batch must contain at least one record: %s", numRecords)
+                );
+            }
         }
 
         public int sizeInBytes() {
@@ -565,6 +622,10 @@ public class BatchAccumulator<T> implements Closeable {
             //    to return the LastContainedLogTimestamp of the SnapshotHeaderRecord
             return data.firstBatch().maxTimestamp();
         }
+
+        public boolean drainable(long drainOffset) {
+            return baseOffset + numRecords - 1 < drainOffset;
+        }
     }
 
     private static class SimpleTimer {
