@@ -16,20 +16,20 @@
  */
 package org.apache.kafka.raft;
 
+import org.apache.kafka.common.Uuid;
 import org.apache.kafka.common.utils.LogContext;
 import org.apache.kafka.common.utils.MockTime;
 import org.apache.kafka.common.utils.Utils;
-import org.apache.kafka.raft.internals.ReplicaKey;
-import org.apache.kafka.raft.internals.VoterSet;
-import org.apache.kafka.raft.internals.VoterSetTest;
+
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.CsvSource;
 import org.junit.jupiter.params.provider.ValueSource;
 
 import java.util.Collections;
-import java.util.Map;
 import java.util.Optional;
 import java.util.stream.IntStream;
+import java.util.stream.Stream;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -37,7 +37,7 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class CandidateStateTest {
-    private final VoterSet.VoterNode localNode = VoterSetTest.voterNode(0, true);
+    private final ReplicaKey localReplicaKey = ReplicaKey.of(0, Uuid.randomUuid());
     private final int epoch = 5;
     private final MockTime time = new MockTime();
     private final int electionTimeoutMs = 5000;
@@ -46,8 +46,8 @@ public class CandidateStateTest {
     private CandidateState newCandidateState(VoterSet voters) {
         return new CandidateState(
                 time,
-                localNode.voterKey().id(),
-                localNode.voterKey().directoryId().get(),
+                localReplicaKey.id(),
+                localReplicaKey.directoryId().get(),
                 epoch,
                 voters,
                 Optional.empty(),
@@ -57,184 +57,229 @@ public class CandidateStateTest {
         );
     }
 
-    @Test
-    public void testSingleNodeQuorum() {
-        CandidateState state = newCandidateState(voterSetWithLocal(IntStream.empty()));
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testSingleNodeQuorum(boolean withDirectoryId) {
+        CandidateState state = newCandidateState(voterSetWithLocal(IntStream.empty(), withDirectoryId));
         assertTrue(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
         assertEquals(Collections.emptySet(), state.unrecordedVoters());
     }
 
-    @Test
-    public void testTwoNodeQuorumVoteRejected() {
-        int otherNodeId = 1;
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testTwoNodeQuorumVoteRejected(boolean withDirectoryId) {
+        ReplicaKey otherNode = replicaKey(1, withDirectoryId);
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(Stream.of(otherNode), withDirectoryId)
         );
         assertFalse(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
-        assertEquals(Collections.singleton(otherNodeId), state.unrecordedVoters());
-        assertTrue(state.recordRejectedVote(otherNodeId));
+        assertEquals(Collections.singleton(otherNode), state.unrecordedVoters());
+        assertTrue(state.recordRejectedVote(otherNode.id()));
         assertFalse(state.isVoteGranted());
         assertTrue(state.isVoteRejected());
     }
 
-    @Test
-    public void testTwoNodeQuorumVoteGranted() {
-        int otherNodeId = 1;
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testTwoNodeQuorumVoteGranted(boolean withDirectoryId) {
+        ReplicaKey otherNode = replicaKey(1, withDirectoryId);
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(Stream.of(otherNode), withDirectoryId)
         );
         assertFalse(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
-        assertEquals(Collections.singleton(otherNodeId), state.unrecordedVoters());
-        assertTrue(state.recordGrantedVote(otherNodeId));
+        assertEquals(Collections.singleton(otherNode), state.unrecordedVoters());
+        assertTrue(state.recordGrantedVote(otherNode.id()));
         assertEquals(Collections.emptySet(), state.unrecordedVoters());
         assertFalse(state.isVoteRejected());
         assertTrue(state.isVoteGranted());
     }
 
-    @Test
-    public void testThreeNodeQuorumVoteGranted() {
-        int node1 = 1;
-        int node2 = 2;
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testThreeNodeQuorumVoteGranted(boolean withDirectoryId) {
+        ReplicaKey node1 = replicaKey(1, withDirectoryId);
+        ReplicaKey node2 = replicaKey(2, withDirectoryId);
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(node1, node2))
+            voterSetWithLocal(Stream.of(node1, node2), withDirectoryId)
         );
         assertFalse(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
         assertEquals(Utils.mkSet(node1, node2), state.unrecordedVoters());
-        assertTrue(state.recordGrantedVote(node1));
+        assertTrue(state.recordGrantedVote(node1.id()));
         assertEquals(Collections.singleton(node2), state.unrecordedVoters());
         assertTrue(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
-        assertTrue(state.recordRejectedVote(node2));
+        assertTrue(state.recordRejectedVote(node2.id()));
         assertEquals(Collections.emptySet(), state.unrecordedVoters());
         assertTrue(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
     }
 
-    @Test
-    public void testThreeNodeQuorumVoteRejected() {
-        int node1 = 1;
-        int node2 = 2;
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testThreeNodeQuorumVoteRejected(boolean withDirectoryId) {
+        ReplicaKey node1 = replicaKey(1, withDirectoryId);
+        ReplicaKey node2 = replicaKey(2, withDirectoryId);
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(node1, node2))
+            voterSetWithLocal(Stream.of(node1, node2), withDirectoryId)
         );
         assertFalse(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
         assertEquals(Utils.mkSet(node1, node2), state.unrecordedVoters());
-        assertTrue(state.recordRejectedVote(node1));
+        assertTrue(state.recordRejectedVote(node1.id()));
         assertEquals(Collections.singleton(node2), state.unrecordedVoters());
         assertFalse(state.isVoteGranted());
         assertFalse(state.isVoteRejected());
-        assertTrue(state.recordRejectedVote(node2));
+        assertTrue(state.recordRejectedVote(node2.id()));
         assertEquals(Collections.emptySet(), state.unrecordedVoters());
         assertFalse(state.isVoteGranted());
         assertTrue(state.isVoteRejected());
     }
 
-    @Test
-    public void testCannotRejectVoteFromLocalId() {
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testCannotRejectVoteFromLocalId(boolean withDirectoryId) {
         int otherNodeId = 1;
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(IntStream.of(otherNodeId), withDirectoryId)
         );
         assertThrows(
             IllegalArgumentException.class,
-            () -> state.recordRejectedVote(localNode.voterKey().id())
+            () -> state.recordRejectedVote(localReplicaKey.id())
         );
     }
 
-    @Test
-    public void testCannotChangeVoteGrantedToRejected() {
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testCannotChangeVoteGrantedToRejected(boolean withDirectoryId) {
         int otherNodeId = 1;
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(IntStream.of(otherNodeId), withDirectoryId)
         );
         assertTrue(state.recordGrantedVote(otherNodeId));
         assertThrows(IllegalArgumentException.class, () -> state.recordRejectedVote(otherNodeId));
         assertTrue(state.isVoteGranted());
     }
 
-    @Test
-    public void testCannotChangeVoteRejectedToGranted() {
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testCannotChangeVoteRejectedToGranted(boolean withDirectoryId) {
         int otherNodeId = 1;
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(IntStream.of(otherNodeId), withDirectoryId)
         );
         assertTrue(state.recordRejectedVote(otherNodeId));
         assertThrows(IllegalArgumentException.class, () -> state.recordGrantedVote(otherNodeId));
         assertTrue(state.isVoteRejected());
     }
 
-    @Test
-    public void testCannotGrantOrRejectNonVoters() {
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testCannotGrantOrRejectNonVoters(boolean withDirectoryId) {
         int nonVoterId = 1;
-        CandidateState state = newCandidateState(voterSetWithLocal(IntStream.empty()));
+        CandidateState state = newCandidateState(voterSetWithLocal(IntStream.empty(), withDirectoryId));
         assertThrows(IllegalArgumentException.class, () -> state.recordGrantedVote(nonVoterId));
         assertThrows(IllegalArgumentException.class, () -> state.recordRejectedVote(nonVoterId));
     }
 
-    @Test
-    public void testIdempotentGrant() {
+    @ParameterizedTest
+    @ValueSource(booleans = { true, false })
+    public void testIdempotentGrant(boolean withDirectoryId) {
         int otherNodeId = 1;
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(IntStream.of(otherNodeId), withDirectoryId)
         );
         assertTrue(state.recordGrantedVote(otherNodeId));
         assertFalse(state.recordGrantedVote(otherNodeId));
     }
 
-    @Test
-    public void testIdempotentReject() {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    public void testIdempotentReject(boolean withDirectoryId) {
         int otherNodeId = 1;
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(otherNodeId))
+            voterSetWithLocal(IntStream.of(otherNodeId), withDirectoryId)
         );
         assertTrue(state.recordRejectedVote(otherNodeId));
         assertFalse(state.recordRejectedVote(otherNodeId));
     }
 
     @ParameterizedTest
-    @ValueSource(booleans = {true, false})
-    public void testGrantVote(boolean isLogUpToDate) {
+    @CsvSource({ "true,true", "true,false", "false,true", "false,false" })
+    public void testGrantVote(boolean isLogUpToDate, boolean withDirectoryId) {
+        ReplicaKey node0 = replicaKey(0, withDirectoryId);
+        ReplicaKey node1 = replicaKey(1, withDirectoryId);
+        ReplicaKey node2 = replicaKey(2, withDirectoryId);
+        ReplicaKey node3 = replicaKey(3, withDirectoryId);
+
         CandidateState state = newCandidateState(
-            voterSetWithLocal(IntStream.of(1, 2, 3))
+            voterSetWithLocal(Stream.of(node1, node2, node3), withDirectoryId)
         );
 
-        assertFalse(state.canGrantVote(ReplicaKey.of(0, Optional.empty()), isLogUpToDate));
-        assertFalse(state.canGrantVote(ReplicaKey.of(1, Optional.empty()), isLogUpToDate));
-        assertFalse(state.canGrantVote(ReplicaKey.of(2, Optional.empty()), isLogUpToDate));
-        assertFalse(state.canGrantVote(ReplicaKey.of(3, Optional.empty()), isLogUpToDate));
+        assertFalse(state.canGrantVote(node0, isLogUpToDate));
+        assertFalse(state.canGrantVote(node1, isLogUpToDate));
+        assertFalse(state.canGrantVote(node2, isLogUpToDate));
+        assertFalse(state.canGrantVote(node3, isLogUpToDate));
     }
 
-    @Test
-    public void testElectionState() {
-        VoterSet voters = voterSetWithLocal(IntStream.of(1, 2, 3));
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    public void testElectionState(boolean withDirectoryId) {
+        VoterSet voters = voterSetWithLocal(IntStream.of(1, 2, 3), withDirectoryId);
         CandidateState state = newCandidateState(voters);
         assertEquals(
             ElectionState.withVotedCandidate(
                 epoch,
-                localNode.voterKey(),
+                localReplicaKey,
                 voters.voterIds()
             ),
             state.election()
         );
     }
 
-    @Test
-    public void testInvalidVoterSet() {
+    @ParameterizedTest
+    @ValueSource(booleans = {true, false})
+    public void testInvalidVoterSet(boolean withDirectoryId) {
         assertThrows(
             IllegalArgumentException.class,
-            () -> newCandidateState(VoterSetTest.voterSet(VoterSetTest.voterMap(IntStream.of(1, 2, 3), true)))
+            () -> newCandidateState(
+                VoterSetTest.voterSet(VoterSetTest.voterMap(IntStream.of(1, 2, 3), withDirectoryId))
+            )
         );
     }
 
-    private VoterSet voterSetWithLocal(IntStream remoteVoters) {
-        Map<Integer, VoterSet.VoterNode> voterMap = VoterSetTest.voterMap(remoteVoters, true);
-        voterMap.put(localNode.voterKey().id(), localNode);
+    @Test
+    void testLeaderEndpoints() {
+        CandidateState state = newCandidateState(
+            voterSetWithLocal(IntStream.of(1, 2, 3), true)
+        );
 
-        return VoterSetTest.voterSet(voterMap);
+        assertEquals(Endpoints.empty(), state.leaderEndpoints());
+    }
+
+    private ReplicaKey replicaKey(int id, boolean withDirectoryId) {
+        Uuid directoryId = withDirectoryId ? Uuid.randomUuid() : ReplicaKey.NO_DIRECTORY_ID;
+        return ReplicaKey.of(id, directoryId);
+    }
+
+    private VoterSet voterSetWithLocal(IntStream remoteVoterIds, boolean withDirectoryId) {
+        Stream<ReplicaKey> remoteVoterKeys = remoteVoterIds
+            .boxed()
+            .map(id -> replicaKey(id, withDirectoryId));
+
+        return voterSetWithLocal(remoteVoterKeys, withDirectoryId);
+    }
+
+    private VoterSet voterSetWithLocal(Stream<ReplicaKey> remoteVoterKeys, boolean withDirectoryId) {
+        ReplicaKey actualLocalVoter = withDirectoryId ?
+            localReplicaKey :
+            ReplicaKey.of(localReplicaKey.id(), ReplicaKey.NO_DIRECTORY_ID);
+
+        return VoterSetTest.voterSet(
+            Stream.concat(Stream.of(actualLocalVoter), remoteVoterKeys)
+        );
     }
 }
