@@ -27,13 +27,14 @@ import org.apache.kafka.streams.Topology;
 import org.apache.kafka.streams.integration.utils.EmbeddedKafkaCluster;
 import org.apache.kafka.streams.kstream.Consumed;
 import org.apache.kafka.streams.kstream.Produced;
+
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestInfo;
 import org.junit.jupiter.api.Timeout;
-import org.junit.jupiter.api.Tag;
 
 import java.io.IOException;
 import java.util.HashMap;
@@ -84,7 +85,7 @@ public class MetricsReporterIntegrationTest {
         streamsConfiguration.put(CommonClientConfigs.METRIC_REPORTER_CLASSES_CONFIG, MetricReporterImpl.class.getName());
     }
 
-    final static Map<String, Object> METRIC_NAME_TO_INITIAL_VALUE = new HashMap<>();
+    static final Map<String, Object> METRIC_NAME_TO_INITIAL_VALUE = new HashMap<>();
 
     public static class MetricReporterImpl implements MetricsReporter {
 
@@ -127,4 +128,4 @@ public class MetricsReporterIntegrationTest {
         }
     }
 
-}
\ No newline at end of file
+}
