@@ -16,8 +16,6 @@
  */
 package org.apache.kafka.streams.integration;
 
-import java.util.Collection;
-import java.util.Optional;
 import org.apache.kafka.clients.consumer.ConsumerConfig;
 import org.apache.kafka.common.serialization.Deserializer;
 import org.apache.kafka.common.serialization.Serde;
@@ -26,14 +24,13 @@ import org.apache.kafka.common.serialization.Serdes.StringSerde;
 import org.apache.kafka.common.serialization.StringDeserializer;
 import org.apache.kafka.common.serialization.StringSerializer;
 import org.apache.kafka.streams.KafkaStreams;
+import org.apache.kafka.streams.KeyValueTimestamp;
 import org.apache.kafka.streams.StreamsBuilder;
 import org.apache.kafka.streams.StreamsConfig;
-import org.apache.kafka.streams.KeyValueTimestamp;
 import org.apache.kafka.streams.StreamsConfig.InternalConfig;
 import org.apache.kafka.streams.integration.utils.EmbeddedKafkaCluster;
 import org.apache.kafka.streams.integration.utils.IntegrationTestUtils;
 import org.apache.kafka.streams.kstream.Consumed;
-import org.apache.kafka.streams.kstream.EmitStrategy;
 import org.apache.kafka.streams.kstream.EmitStrategy.StrategyType;
 import org.apache.kafka.streams.kstream.JoinWindows;
 import org.apache.kafka.streams.kstream.KStream;
@@ -47,29 +44,27 @@ import org.apache.kafka.streams.kstream.UnlimitedWindows;
 import org.apache.kafka.streams.kstream.Windowed;
 import org.apache.kafka.streams.kstream.WindowedSerdes;
 import org.apache.kafka.streams.kstream.internals.TimeWindow;
-import org.apache.kafka.test.IntegrationTest;
 import org.apache.kafka.test.MockAggregator;
 import org.apache.kafka.test.MockInitializer;
 import org.apache.kafka.test.TestUtils;
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
-import org.junit.rules.TestName;
+
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.TestInfo;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.CsvSource;
+import org.junit.jupiter.params.provider.EnumSource;
 
 import java.io.IOException;
 import java.util.Arrays;
-import java.util.List;
-import java.util.Properties;
 import java.util.Collections;
-
-import org.junit.rules.Timeout;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameter;
+import java.util.List;
+import java.util.Optional;
+import java.util.Properties;
 
 import static java.time.Duration.ofMillis;
 import static java.time.Instant.ofEpochMilli;
@@ -80,14 +75,12 @@ import static org.apache.kafka.common.utils.Utils.mkProperties;
 import static org.apache.kafka.streams.integration.utils.IntegrationTestUtils.safeUniqueTestName;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.core.Is.is;
-import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 @SuppressWarnings({"unchecked"})
-@Category({IntegrationTest.class})
-@RunWith(Parameterized.class)
+@Tag("integration")
+@Timeout(600)
 public class TimeWindowedKStreamIntegrationTest {
-    @Rule
-    public Timeout globalTimeout = Timeout.seconds(600);
 
     private static final int NUM_BROKERS = 1;
 
@@ -97,12 +90,12 @@ public class TimeWindowedKStreamIntegrationTest {
         )
     );
 
-    @BeforeClass
+    @BeforeAll
     public static void startCluster() throws IOException {
         CLUSTER.start();
     }
 
-    @AfterClass
+    @AfterAll
     public static void closeCluster() {
         CLUSTER.stop();
     }
@@ -114,37 +107,12 @@ public class TimeWindowedKStreamIntegrationTest {
     private String streamOneInput;
     private String streamTwoInput;
     private String outputTopic;
-
-    @Rule
-    public TestName testName = new TestName();
-
-    @Parameter
-    public StrategyType type;
-
-    @Parameter(1)
-    public boolean withCache;
-
-    @Parameter(2)
-    public EmitStrategy emitStrategy;
-
-    private boolean emitFinal;
-
     private String safeTestName;
 
-    @Parameterized.Parameters(name = "{0}_{1}")
-    public static Collection<Object[]> getEmitStrategy() {
-        return asList(new Object[][] {
-            {StrategyType.ON_WINDOW_UPDATE, true, EmitStrategy.onWindowUpdate()},
-            {StrategyType.ON_WINDOW_UPDATE, false, EmitStrategy.onWindowUpdate()},
-            {StrategyType.ON_WINDOW_CLOSE, true, EmitStrategy.onWindowClose()},
-            {StrategyType.ON_WINDOW_CLOSE, false, EmitStrategy.onWindowClose()}
-        });
-    }
-
-    @Before
-    public void before() throws InterruptedException {
+    @BeforeEach
+    public void before(final TestInfo testInfo) throws InterruptedException {
         builder = new StreamsBuilder();
-        safeTestName = safeUniqueTestName(testName);
+        safeTestName = safeUniqueTestName(testInfo);
         createTopics();
         streamsConfiguration = new Properties();
         streamsConfiguration.put(StreamsConfig.APPLICATION_ID_CONFIG, "app-" + safeTestName);
@@ -157,11 +125,9 @@ public class TimeWindowedKStreamIntegrationTest {
         streamsConfiguration.put(StreamsConfig.DEFAULT_VALUE_SERDE_CLASS_CONFIG, Serdes.String().getClass());
         streamsConfiguration.put(InternalConfig.EMIT_INTERVAL_MS_KSTREAMS_WINDOWED_AGGREGATION, 0); // Always process
         streamsConfiguration.put(StreamsConfig.WINDOW_STORE_CHANGE_LOG_ADDITIONAL_RETENTION_MS_CONFIG, Long.MAX_VALUE); // Don't expire changelog
-
-        emitFinal = emitStrategy.type() == StrategyType.ON_WINDOW_CLOSE;
     }
 
-    @After
+    @AfterEach
     public void whenShuttingDown() throws IOException {
         if (kafkaStreams != null) {
             kafkaStreams.close();
@@ -170,8 +136,9 @@ public class TimeWindowedKStreamIntegrationTest {
         IntegrationTestUtils.purgeLocalStreamsState(streamsConfiguration);
     }
 
-    @Test
-    public void shouldAggregateWindowedWithNoGrace() throws Exception {
+    @ParameterizedTest
+    @CsvSource({"ON_WINDOW_UPDATE, true", "ON_WINDOW_UPDATE, false", "ON_WINDOW_CLOSE, true", "ON_WINDOW_CLOSE, false"})
+    public void shouldAggregateWindowedWithNoGrace(final StrategyType type, final boolean withCache) throws Exception {
         produceMessages(
             streamOneInput,
             new KeyValueTimestamp<>("A", "1", 0),
@@ -187,11 +154,11 @@ public class TimeWindowedKStreamIntegrationTest {
         builder.stream(streamOneInput, Consumed.with(Serdes.String(), Serdes.String()))
             .groupByKey()
             .windowedBy(TimeWindows.ofSizeWithNoGrace(ofMillis(10L)).advanceBy(ofMillis(5L)))
-            .emitStrategy(emitStrategy)
+            .emitStrategy(StrategyType.forType(type))
             .aggregate(
                 MockInitializer.STRING_INIT,
                 MockAggregator.TOSTRING_ADDER,
-                getMaterialized()
+                getMaterialized(withCache)
             )
             .toStream()
             .to(outputTopic, Produced.with(windowedSerde, new StringSerde()));
@@ -203,6 +170,7 @@ public class TimeWindowedKStreamIntegrationTest {
         // observedStreamTime : 15, retentionPeriod: 10, actualFrom: 5, timeTo: 5, timeFrom: 1
         // observedStreamTime : 25, retentionPeriod: 10, actualFrom: 15, timeTo: 15, timeFrom: 6
 
+        final boolean emitFinal = type == StrategyType.ON_WINDOW_CLOSE;
         final List<KeyValueTimestamp<Windowed<String>, String>> windowedMessages = receiveMessagesWithTimestamp(
                 new TimeWindowedDeserializer<>(new StringDeserializer(), 10L),
                 new StringDeserializer(),
@@ -238,8 +206,9 @@ public class TimeWindowedKStreamIntegrationTest {
         assertThat(windowedMessages, is(expectResult));
     }
 
-    @Test
-    public void shouldAggregateWindowedWithGrace() throws Exception {
+    @ParameterizedTest
+    @CsvSource({"ON_WINDOW_UPDATE, true", "ON_WINDOW_UPDATE, false", "ON_WINDOW_CLOSE, true", "ON_WINDOW_CLOSE, false"})
+    public void shouldAggregateWindowedWithGrace(final StrategyType type, final boolean withCache) throws Exception {
         produceMessages(
             streamOneInput,
             new KeyValueTimestamp<>("A", "1", 0),
@@ -255,11 +224,11 @@ public class TimeWindowedKStreamIntegrationTest {
         builder.stream(streamOneInput, Consumed.with(Serdes.String(), Serdes.String()))
             .groupByKey()
             .windowedBy(TimeWindows.ofSizeAndGrace(ofMillis(10L), ofMillis(5)).advanceBy(ofMillis(5L)))
-            .emitStrategy(emitStrategy)
+            .emitStrategy(StrategyType.forType(type))
             .aggregate(
                 MockInitializer.STRING_INIT,
                 MockAggregator.TOSTRING_ADDER,
-                getMaterialized()
+                getMaterialized(withCache)
             )
             .toStream()
             .to(outputTopic, Produced.with(windowedSerde, new StringSerde()));
@@ -270,6 +239,7 @@ public class TimeWindowedKStreamIntegrationTest {
         // observedStreamTime : 15, retentionPeriod: 15, actualFrom: 0, timeTo: 0, timeFrom: 0
         // observedStreamTime : 25, retentionPeriod: 15, actualFrom: 10, timeTo: 10, timeFrom: 1
 
+        final boolean emitFinal = type == StrategyType.ON_WINDOW_CLOSE;
         final List<KeyValueTimestamp<Windowed<String>, String>> windowedMessages = receiveMessagesWithTimestamp(
             new TimeWindowedDeserializer<>(new StringDeserializer(), 10L),
             new StringDeserializer(),
@@ -306,8 +276,9 @@ public class TimeWindowedKStreamIntegrationTest {
         assertThat(windowedMessages, is(expectResult));
     }
 
-    @Test
-    public void shouldRestoreAfterJoinRestart() throws Exception {
+    @ParameterizedTest
+    @CsvSource({"ON_WINDOW_UPDATE, true", "ON_WINDOW_UPDATE, false", "ON_WINDOW_CLOSE, true", "ON_WINDOW_CLOSE, false"})
+    public void shouldRestoreAfterJoinRestart(final StrategyType type, final boolean withCache) throws Exception {
         produceMessages(
             streamOneInput,
             new KeyValueTimestamp<>("A", "L1", 0),
@@ -339,11 +310,11 @@ public class TimeWindowedKStreamIntegrationTest {
 
         joinedStream.groupByKey()
             .windowedBy(TimeWindows.ofSizeWithNoGrace(ofMillis(10L)).advanceBy(ofMillis(5L)))
-            .emitStrategy(emitStrategy)
+            .emitStrategy(StrategyType.forType(type))
             .aggregate(
                 MockInitializer.STRING_INIT,
                 MockAggregator.TOSTRING_ADDER,
-                getMaterialized()
+                getMaterialized(withCache)
             )
             .toStream()
             .to(outputTopic, Produced.with(windowedSerde, new StringSerde()));
@@ -351,6 +322,7 @@ public class TimeWindowedKStreamIntegrationTest {
         startStreams();
 
         // ON_WINDOW_CLOSE expires all records.
+        final boolean emitFinal = type == StrategyType.ON_WINDOW_CLOSE;
         List<KeyValueTimestamp<Windowed<String>, String>> windowedMessages = receiveMessagesWithTimestamp(
             new TimeWindowedDeserializer<>(new StringDeserializer(), 10L),
             new StringDeserializer(),
@@ -442,18 +414,20 @@ public class TimeWindowedKStreamIntegrationTest {
         assertThat(windowedMessages, is(expectResult));
     }
 
-    @Test
-    public void shouldThrowUnlimitedWindows() {
+    @ParameterizedTest
+    @EnumSource(StrategyType.class)
+    public void shouldThrowUnlimitedWindows(final StrategyType type) {
         final TimeWindowedKStream<String, String> windowedStream = builder.stream(streamOneInput, Consumed.with(Serdes.String(), Serdes.String()))
             .groupByKey()
             .windowedBy(
             UnlimitedWindows.of().startOn(ofEpochMilli(0))
         );
 
+        final boolean emitFinal = type == StrategyType.ON_WINDOW_CLOSE;
         if (emitFinal) {
-            assertThrows(IllegalArgumentException.class, () -> windowedStream.emitStrategy(emitStrategy));
+            assertThrows(IllegalArgumentException.class, () -> windowedStream.emitStrategy(StrategyType.forType(type)));
         } else {
-            windowedStream.emitStrategy(emitStrategy);
+            windowedStream.emitStrategy(StrategyType.forType(type));
         }
     }
 
@@ -471,7 +445,7 @@ public class TimeWindowedKStreamIntegrationTest {
         );
     }
 
-    private Materialized getMaterialized() {
+    private Materialized getMaterialized(final boolean withCache) {
         if (withCache) {
             return Materialized.with(null, new StringSerde()).withCachingEnabled();
         }
