@@ -24,23 +24,32 @@ import org.apache.kafka.clients.producer.ProducerConfig;
 import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.common.Cluster;
 import org.apache.kafka.common.KafkaException;
+import org.apache.kafka.common.Metric;
+import org.apache.kafka.common.MetricName;
 import org.apache.kafka.common.Node;
 import org.apache.kafka.common.PartitionInfo;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.errors.InvalidPidMappingException;
 import org.apache.kafka.common.errors.InvalidProducerEpochException;
 import org.apache.kafka.common.errors.ProducerFencedException;
 import org.apache.kafka.common.errors.TimeoutException;
 import org.apache.kafka.common.errors.UnknownProducerIdException;
 import org.apache.kafka.common.header.internals.RecordHeaders;
 import org.apache.kafka.common.utils.LogContext;
+import org.apache.kafka.common.utils.Time;
 import org.apache.kafka.streams.KafkaClientSupplier;
 import org.apache.kafka.streams.StreamsConfig;
 import org.apache.kafka.streams.errors.StreamsException;
 import org.apache.kafka.streams.errors.TaskMigratedException;
 import org.apache.kafka.streams.processor.TaskId;
 import org.apache.kafka.test.MockClientSupplier;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 
 import java.util.Collections;
 import java.util.HashMap;
@@ -50,20 +59,33 @@ import java.util.UUID;
 
 import static org.apache.kafka.common.utils.Utils.mkEntry;
 import static org.apache.kafka.common.utils.Utils.mkMap;
-import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.expectLastCall;
-import static org.easymock.EasyMock.mock;
-import static org.easymock.EasyMock.replay;
-import static org.easymock.EasyMock.reset;
-import static org.easymock.EasyMock.verify;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.closeTo;
+import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.sameInstance;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.STRICT_STUBS)
 public class StreamsProducerTest {
+    private static final double BUFFER_POOL_WAIT_TIME = 1;
+    private static final double FLUSH_TME = 2;
+    private static final double TXN_INIT_TIME = 3;
+    private static final double TXN_BEGIN_TIME = 4;
+    private static final double TXN_SEND_OFFSETS_TIME = 5;
+    private static final double TXN_COMMIT_TIME = 6;
+    private static final double TXN_ABORT_TIME = 7;
+    private static final double METADATA_WAIT_TIME = 8;
 
     private final LogContext logContext = new LogContext("test ");
     private final String topic = "topic";
@@ -93,6 +115,9 @@ public class StreamsProducerTest {
         mkEntry(StreamsConfig.PROCESSING_GUARANTEE_CONFIG, StreamsConfig.EXACTLY_ONCE_V2))
     );
 
+    private final Time mockTime = mock(Time.class);
+
+    @SuppressWarnings("unchecked")
     final Producer<byte[], byte[]> mockedProducer = mock(Producer.class);
     final KafkaClientSupplier clientSupplier = new MockClientSupplier() {
         @Override
@@ -106,7 +131,8 @@ public class StreamsProducerTest {
         clientSupplier,
         null,
         null,
-        logContext
+        logContext,
+        mockTime
     );
     final StreamsProducer eosAlphaStreamsProducerWithMock = new StreamsProducer(
         eosAlphaConfig,
@@ -114,7 +140,8 @@ public class StreamsProducerTest {
         clientSupplier,
         new TaskId(0, 0),
         null,
-        logContext
+        logContext,
+        mockTime
     );
 
     private final MockClientSupplier mockClientSupplier = new MockClientSupplier();
@@ -136,9 +163,7 @@ public class StreamsProducerTest {
         mkEntry(new TopicPartition(topic, 0), new OffsetAndMetadata(0L, null))
     );
 
-
-
-    @Before
+    @BeforeEach
     public void before() {
         mockClientSupplier.setCluster(cluster);
         nonEosStreamsProducer =
@@ -148,7 +173,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 null,
                 null,
-                logContext
+                logContext,
+                mockTime
             );
         nonEosMockProducer = mockClientSupplier.producers.get(0);
 
@@ -161,7 +187,8 @@ public class StreamsProducerTest {
                 eosAlphaMockClientSupplier,
                 new TaskId(0, 0),
                 null,
-                logContext
+                logContext,
+                mockTime
             );
         eosAlphaStreamsProducer.initTransaction();
         eosAlphaMockProducer = eosAlphaMockClientSupplier.producers.get(0);
@@ -175,10 +202,12 @@ public class StreamsProducerTest {
                 eosBetaMockClientSupplier,
                 null,
                 UUID.randomUUID(),
-                logContext
+                logContext,
+                mockTime
             );
         eosBetaStreamsProducer.initTransaction();
         eosBetaMockProducer = eosBetaMockClientSupplier.producers.get(0);
+        when(mockTime.nanoseconds()).thenReturn(Time.SYSTEM.nanoseconds());
     }
 
 
@@ -187,6 +216,34 @@ public class StreamsProducerTest {
 
     // functional tests
 
+    @Test
+    public void shouldResetTransactionInFlightOnClose() {
+        // given:
+        eosBetaStreamsProducer.send(
+            new ProducerRecord<>("topic", new byte[1]), (metadata, error) -> { });
+        assertThat(eosBetaStreamsProducer.transactionInFlight(), is(true));
+
+        // when:
+        eosBetaStreamsProducer.close();
+
+        // then:
+        assertThat(eosBetaStreamsProducer.transactionInFlight(), is(false));
+    }
+
+    @Test
+    public void shouldResetTransactionInFlightOnReset() {
+        // given:
+        eosBetaStreamsProducer.send(
+            new ProducerRecord<>("topic", new byte[1]), (metadata, error) -> { });
+        assertThat(eosBetaStreamsProducer.transactionInFlight(), is(true));
+
+        // when:
+        eosBetaStreamsProducer.resetProducer();
+
+        // then:
+        assertThat(eosBetaStreamsProducer.transactionInFlight(), is(false));
+    }
+
     @Test
     public void shouldCreateProducer() {
         assertThat(mockClientSupplier.producers.size(), is(1));
@@ -196,47 +253,32 @@ public class StreamsProducerTest {
     @Test
     public void shouldForwardCallToPartitionsFor() {
         final List<PartitionInfo> expectedPartitionInfo = Collections.emptyList();
-        expect(mockedProducer.partitionsFor("topic")).andReturn(expectedPartitionInfo);
-        replay(mockedProducer);
+        when(mockedProducer.partitionsFor(topic)).thenReturn(expectedPartitionInfo);
 
         final List<PartitionInfo> partitionInfo = streamsProducerWithMock.partitionsFor(topic);
 
         assertThat(partitionInfo, sameInstance(expectedPartitionInfo));
-        verify(mockedProducer);
     }
 
     @Test
     public void shouldForwardCallToFlush() {
-        mockedProducer.flush();
-        expectLastCall();
-        replay(mockedProducer);
-
         streamsProducerWithMock.flush();
-
-        verify(mockedProducer);
+        verify(mockedProducer).flush();
     }
 
-    @SuppressWarnings({"unchecked", "rawtypes"})
+    @SuppressWarnings({"rawtypes", "unchecked"})
     @Test
     public void shouldForwardCallToMetrics() {
         final Map metrics = new HashMap<>();
-        expect(mockedProducer.metrics()).andReturn(metrics);
-        replay(mockedProducer);
+        when(mockedProducer.metrics()).thenReturn(metrics);
 
         assertSame(metrics, streamsProducerWithMock.metrics());
-
-        verify(mockedProducer);
     }
 
     @Test
     public void shouldForwardCallToClose() {
-        mockedProducer.close();
-        expectLastCall();
-        replay(mockedProducer);
-
         streamsProducerWithMock.close();
-
-        verify(mockedProducer);
+        verify(mockedProducer).close();
     }
 
     // error handling tests
@@ -251,7 +293,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 new TaskId(0, 0),
                 UUID.randomUUID(),
-                logContext)
+                logContext,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("config cannot be null"));
@@ -267,7 +310,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 new TaskId(0, 0),
                 UUID.randomUUID(),
-                logContext)
+                logContext,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("threadId cannot be null"));
@@ -283,7 +327,8 @@ public class StreamsProducerTest {
                 null,
                 new TaskId(0, 0),
                 UUID.randomUUID(),
-                logContext)
+                logContext,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("clientSupplier cannot be null"));
@@ -299,7 +344,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 new TaskId(0, 0),
                 UUID.randomUUID(),
-                null)
+                null,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("logContext cannot be null"));
@@ -332,10 +378,10 @@ public class StreamsProducerTest {
 
     @Test
     public void shouldNotSetTransactionIdIfEosDisabled() {
+        final Map<String, Object> producerConfig = new HashMap<>();
         final StreamsConfig mockConfig = mock(StreamsConfig.class);
-        expect(mockConfig.getProducerConfigs("threadId-producer")).andReturn(mock(Map.class));
-        expect(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).andReturn(StreamsConfig.AT_LEAST_ONCE).anyTimes();
-        replay(mockConfig);
+        when(mockConfig.getProducerConfigs("threadId-producer")).thenReturn(producerConfig);
+        when(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).thenReturn(StreamsConfig.AT_LEAST_ONCE);
 
         new StreamsProducer(
             mockConfig,
@@ -343,8 +389,11 @@ public class StreamsProducerTest {
             mockClientSupplier,
             null,
             null,
-            logContext
+            logContext,
+            mockTime
         );
+
+        assertFalse(producerConfig.containsKey(ProducerConfig.TRANSACTIONAL_ID_CONFIG));
     }
 
     @Test
@@ -445,16 +494,11 @@ public class StreamsProducerTest {
     @SuppressWarnings("deprecation")
     @Test
     public void shouldSetTransactionIdUsingTaskIdIfEosAlphaEnabled() {
-        final Map<String, Object> mockMap = mock(Map.class);
-        expect(mockMap.put(ProducerConfig.TRANSACTIONAL_ID_CONFIG, "appId-0_0")).andReturn(null);
-        expect(mockMap.get(ProducerConfig.TRANSACTIONAL_ID_CONFIG)).andReturn("appId-0_0");
-
+        final Map<String, Object> producerConfig = new HashMap<>();
         final StreamsConfig mockConfig = mock(StreamsConfig.class);
-        expect(mockConfig.getProducerConfigs("threadId-0_0-producer")).andReturn(mockMap);
-        expect(mockConfig.getString(StreamsConfig.APPLICATION_ID_CONFIG)).andReturn("appId");
-        expect(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).andReturn(StreamsConfig.EXACTLY_ONCE);
-
-        replay(mockMap, mockConfig);
+        when(mockConfig.getProducerConfigs("threadId-0_0-producer")).thenReturn(producerConfig);
+        when(mockConfig.getString(StreamsConfig.APPLICATION_ID_CONFIG)).thenReturn("appId");
+        when(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).thenReturn(StreamsConfig.EXACTLY_ONCE);
 
         new StreamsProducer(
             mockConfig,
@@ -462,26 +506,21 @@ public class StreamsProducerTest {
             eosAlphaMockClientSupplier,
             new TaskId(0, 0),
             null,
-            logContext
+            logContext,
+            mockTime
         );
 
-        verify(mockMap);
+        assertEquals("appId-0_0", producerConfig.get(ProducerConfig.TRANSACTIONAL_ID_CONFIG));
     }
 
     @Test
     public void shouldSetTransactionIdUsingProcessIdIfEosV2Enabled() {
         final UUID processId = UUID.randomUUID();
-
-        final Map<String, Object> mockMap = mock(Map.class);
-        expect(mockMap.put(ProducerConfig.TRANSACTIONAL_ID_CONFIG, "appId-" + processId + "-0")).andReturn(null);
-        expect(mockMap.get(ProducerConfig.TRANSACTIONAL_ID_CONFIG)).andReturn("appId-" + processId);
-
+        final Map<String, Object> producerConfig = new HashMap<>();
         final StreamsConfig mockConfig = mock(StreamsConfig.class);
-        expect(mockConfig.getProducerConfigs("threadId-StreamThread-0-producer")).andReturn(mockMap);
-        expect(mockConfig.getString(StreamsConfig.APPLICATION_ID_CONFIG)).andReturn("appId");
-        expect(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).andReturn(StreamsConfig.EXACTLY_ONCE_V2).anyTimes();
-
-        replay(mockMap, mockConfig);
+        when(mockConfig.getProducerConfigs("threadId-StreamThread-0-producer")).thenReturn(producerConfig);
+        when(mockConfig.getString(StreamsConfig.APPLICATION_ID_CONFIG)).thenReturn("appId");
+        when(mockConfig.getString(StreamsConfig.PROCESSING_GUARANTEE_CONFIG)).thenReturn(StreamsConfig.EXACTLY_ONCE_V2);
 
         new StreamsProducer(
             mockConfig,
@@ -489,10 +528,11 @@ public class StreamsProducerTest {
             eosAlphaMockClientSupplier,
             null,
             processId,
-            logContext
+            logContext,
+            mockTime
         );
 
-        verify(mockMap);
+        assertEquals("appId-" + processId + "-0", producerConfig.get(ProducerConfig.TRANSACTIONAL_ID_CONFIG));
     }
 
     @Test
@@ -535,18 +575,13 @@ public class StreamsProducerTest {
 
     @Test
     public void shouldBeginTxOnEosCommit() {
-        mockedProducer.initTransactions();
-        mockedProducer.beginTransaction();
-        mockedProducer.sendOffsetsToTransaction(offsetsAndMetadata, new ConsumerGroupMetadata("appId"));
-        mockedProducer.commitTransaction();
-        expectLastCall();
-        replay(mockedProducer);
-
         eosAlphaStreamsProducerWithMock.initTransaction();
-
         eosAlphaStreamsProducerWithMock.commitTransaction(offsetsAndMetadata, new ConsumerGroupMetadata("appId"));
 
-        verify(mockedProducer);
+        verify(mockedProducer).initTransactions();
+        verify(mockedProducer).beginTransaction();
+        verify(mockedProducer).sendOffsetsToTransaction(offsetsAndMetadata, new ConsumerGroupMetadata("appId"));
+        verify(mockedProducer).commitTransaction();
     }
 
     @Test
@@ -573,38 +608,22 @@ public class StreamsProducerTest {
 
     @Test
     public void shouldCommitTxWithApplicationIdOnEosAlphaCommit() {
-        mockedProducer.initTransactions();
-        expectLastCall();
-        mockedProducer.beginTransaction();
-        expectLastCall();
-        expect(mockedProducer.send(record, null)).andReturn(null);
-        mockedProducer.sendOffsetsToTransaction(null, new ConsumerGroupMetadata("appId"));
-        expectLastCall();
-        mockedProducer.commitTransaction();
-        expectLastCall();
-        replay(mockedProducer);
+        when(mockedProducer.send(record, null)).thenReturn(null);
 
         eosAlphaStreamsProducerWithMock.initTransaction();
         // call `send()` to start a transaction
         eosAlphaStreamsProducerWithMock.send(record, null);
-
         eosAlphaStreamsProducerWithMock.commitTransaction(null, new ConsumerGroupMetadata("appId"));
 
-        verify(mockedProducer);
+        verify(mockedProducer).initTransactions();
+        verify(mockedProducer).beginTransaction();
+        verify(mockedProducer).sendOffsetsToTransaction(null, new ConsumerGroupMetadata("appId"));
+        verify(mockedProducer).commitTransaction();
     }
 
     @Test
     public void shouldCommitTxWithConsumerGroupMetadataOnEosBetaCommit() {
-        mockedProducer.initTransactions();
-        expectLastCall();
-        mockedProducer.beginTransaction();
-        expectLastCall();
-        expect(mockedProducer.send(record, null)).andReturn(null);
-        mockedProducer.sendOffsetsToTransaction(null, new ConsumerGroupMetadata("appId"));
-        expectLastCall();
-        mockedProducer.commitTransaction();
-        expectLastCall();
-        replay(mockedProducer);
+        when(mockedProducer.send(record, null)).thenReturn(null);
 
         final StreamsProducer streamsProducer = new StreamsProducer(
             eosBetaConfig,
@@ -612,15 +631,18 @@ public class StreamsProducerTest {
             clientSupplier,
             null,
             UUID.randomUUID(),
-            logContext
+            logContext,
+            mockTime
         );
         streamsProducer.initTransaction();
         // call `send()` to start a transaction
         streamsProducer.send(record, null);
-
         streamsProducer.commitTransaction(null, new ConsumerGroupMetadata("appId"));
 
-        verify(mockedProducer);
+        verify(mockedProducer).initTransactions();
+        verify(mockedProducer).beginTransaction();
+        verify(mockedProducer).sendOffsetsToTransaction(null, new ConsumerGroupMetadata("appId"));
+        verify(mockedProducer).commitTransaction();
     }
 
     @Test
@@ -642,15 +664,10 @@ public class StreamsProducerTest {
 
     @Test
     public void shouldSkipAbortTxOnEosAbortIfNotTxInFlight() {
-        mockedProducer.initTransactions();
-        expectLastCall();
-        replay(mockedProducer);
-
         eosAlphaStreamsProducerWithMock.initTransaction();
-
         eosAlphaStreamsProducerWithMock.abortTransaction();
 
-        verify(mockedProducer);
+        verify(mockedProducer).initTransactions();
     }
 
     // error handling tests
@@ -665,7 +682,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 null,
                 UUID.randomUUID(),
-                logContext)
+                logContext,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("taskId cannot be null for exactly-once alpha"));
@@ -681,7 +699,8 @@ public class StreamsProducerTest {
                 mockClientSupplier,
                 new TaskId(0, 0),
                 null,
-                logContext)
+                logContext,
+                mockTime)
         );
 
         assertThat(thrown.getMessage(), is("processId cannot be null for exactly-once v2"));
@@ -704,7 +723,8 @@ public class StreamsProducerTest {
             clientSupplier,
             new TaskId(0, 0),
             null,
-            logContext
+            logContext,
+            mockTime
         );
 
         final TimeoutException thrown = assertThrows(
@@ -724,7 +744,8 @@ public class StreamsProducerTest {
                 eosAlphaMockClientSupplier,
                 new TaskId(0, 0),
                 null,
-                logContext
+                logContext,
+                mockTime
             );
 
         final IllegalStateException thrown = assertThrows(
@@ -744,7 +765,8 @@ public class StreamsProducerTest {
                 eosBetaMockClientSupplier,
                 null,
                 UUID.randomUUID(),
-                logContext
+                logContext,
+                mockTime
             );
 
         final IllegalStateException thrown = assertThrows(
@@ -772,7 +794,8 @@ public class StreamsProducerTest {
             clientSupplier,
             new TaskId(0, 0),
             null,
-            logContext
+            logContext,
+            mockTime
         );
 
         final StreamsException thrown = assertThrows(
@@ -801,7 +824,8 @@ public class StreamsProducerTest {
             clientSupplier,
             new TaskId(0, 0),
             null,
-            logContext
+            logContext,
+            mockTime
         );
 
         final RuntimeException thrown = assertThrows(
@@ -861,6 +885,11 @@ public class StreamsProducerTest {
         testThrowTaskMigratedExceptionOnEosSend(new ProducerFencedException("KABOOM!"));
     }
 
+    @Test
+    public void shouldThrowTaskMigratedExceptionOnEosSendPInvalidPidMapping() {
+        testThrowTaskMigratedExceptionOnEosSend(new InvalidPidMappingException("KABOOM!"));
+    }
+
     @Test
     public void shouldThrowTaskMigratedExceptionOnEosSendInvalidEpoch() {
         testThrowTaskMigratedExceptionOnEosSend(new InvalidProducerEpochException("KABOOM!"));
@@ -909,6 +938,12 @@ public class StreamsProducerTest {
         testThrowTaskMigrateExceptionOnEosSendOffset(new ProducerFencedException("KABOOM!"));
     }
 
+    @Test
+    public void shouldThrowTaskMigrateExceptionOnEosSendOffsetInvalidPidMapping() {
+        // cannot use `eosMockProducer.fenceProducer()` because this would already trigger in `beginTransaction()`
+        testThrowTaskMigrateExceptionOnEosSendOffset(new InvalidPidMappingException("KABOOM!"));
+    }
+
     @Test
     public void shouldThrowTaskMigrateExceptionOnEosSendOffsetInvalidEpoch() {
         // cannot use `eosMockProducer.fenceProducer()` because this would already trigger in `beginTransaction()`
@@ -971,6 +1006,11 @@ public class StreamsProducerTest {
         testThrowTaskMigratedExceptionOnEos(new ProducerFencedException("KABOOM!"));
     }
 
+    @Test
+    public void shouldThrowTaskMigratedExceptionOnEosCommitWithInvalidPidMapping() {
+        testThrowTaskMigratedExceptionOnEos(new InvalidPidMappingException("KABOOM!"));
+    }
+
     @Test
     public void shouldThrowTaskMigratedExceptionOnEosCommitWithInvalidEpoch() {
         testThrowTaskMigratedExceptionOnEos(new InvalidProducerEpochException("KABOOM!"));
@@ -1029,26 +1069,27 @@ public class StreamsProducerTest {
         testSwallowExceptionOnEosAbortTx(new ProducerFencedException("KABOOM!"));
     }
 
+    @Test
+    public void shouldSwallowExceptionOnEosAbortTxInvalidPidMapping() {
+        testSwallowExceptionOnEosAbortTx(new InvalidPidMappingException("KABOOM!"));
+    }
+
     @Test
     public void shouldSwallowExceptionOnEosAbortTxInvalidEpoch() {
         testSwallowExceptionOnEosAbortTx(new InvalidProducerEpochException("KABOOM!"));
     }
 
     private void testSwallowExceptionOnEosAbortTx(final RuntimeException exception) {
-        mockedProducer.initTransactions();
-        mockedProducer.beginTransaction();
-        expect(mockedProducer.send(record, null)).andReturn(null);
-        mockedProducer.abortTransaction();
-        expectLastCall().andThrow(exception);
-        replay(mockedProducer);
+        when(mockedProducer.send(record, null)).thenReturn(null);
+        doThrow(exception).when(mockedProducer).abortTransaction();
 
         eosAlphaStreamsProducerWithMock.initTransaction();
         // call `send()` to start a transaction
         eosAlphaStreamsProducerWithMock.send(record, null);
-
         eosAlphaStreamsProducerWithMock.abortTransaction();
 
-        verify(mockedProducer);
+        verify(mockedProducer).initTransactions();
+        verify(mockedProducer).beginTransaction();
     }
 
     @Test
@@ -1105,20 +1146,122 @@ public class StreamsProducerTest {
             clientSupplier,
             null,
             UUID.randomUUID(),
-            logContext
+            logContext,
+            mockTime
         );
         streamsProducer.initTransaction();
 
-        reset(mockedProducer);
-        mockedProducer.close();
-        mockedProducer.initTransactions();
-        expectLastCall();
-        replay(mockedProducer);
+        when(mockedProducer.metrics()).thenReturn(Collections.emptyMap());
 
         streamsProducer.resetProducer();
         streamsProducer.initTransaction();
 
-        verify(mockedProducer);
+        verify(mockedProducer).close();
+
+        // streamsProducer.resetProducer() should reset 'transactionInitialized' field so that subsequent call of the
+        // streamsProducer.initTransactions() method can start new transaction.
+        // Therefore, mockedProducer.initTransactions() is expected to be called twice.
+        verify(mockedProducer, times(2)).initTransactions();
     }
 
+    @Test
+    public void shouldComputeTotalBlockedTime() {
+        setProducerMetrics(
+            nonEosMockProducer,
+            BUFFER_POOL_WAIT_TIME,
+            FLUSH_TME,
+            TXN_INIT_TIME,
+            TXN_BEGIN_TIME,
+            TXN_SEND_OFFSETS_TIME,
+            TXN_COMMIT_TIME,
+            TXN_ABORT_TIME,
+            METADATA_WAIT_TIME
+        );
+
+        final double expectedTotalBlocked = BUFFER_POOL_WAIT_TIME + FLUSH_TME + TXN_INIT_TIME +
+            TXN_BEGIN_TIME + TXN_SEND_OFFSETS_TIME +  TXN_COMMIT_TIME + TXN_ABORT_TIME +
+            METADATA_WAIT_TIME;
+        assertThat(nonEosStreamsProducer.totalBlockedTime(), closeTo(expectedTotalBlocked, 0.01));
+    }
+
+    @Test
+    public void shouldComputeTotalBlockedTimeAfterReset() {
+        setProducerMetrics(
+            eosBetaMockProducer,
+            BUFFER_POOL_WAIT_TIME,
+            FLUSH_TME,
+            TXN_INIT_TIME,
+            TXN_BEGIN_TIME,
+            TXN_SEND_OFFSETS_TIME,
+            TXN_COMMIT_TIME,
+            TXN_ABORT_TIME,
+            METADATA_WAIT_TIME
+        );
+        final double expectedTotalBlocked = BUFFER_POOL_WAIT_TIME + FLUSH_TME + TXN_INIT_TIME +
+            TXN_BEGIN_TIME + TXN_SEND_OFFSETS_TIME +  TXN_COMMIT_TIME + TXN_ABORT_TIME +
+            METADATA_WAIT_TIME;
+        assertThat(eosBetaStreamsProducer.totalBlockedTime(), equalTo(expectedTotalBlocked));
+        final long closeStart = 1L;
+        final long clodeDelay = 1L;
+        when(mockTime.nanoseconds()).thenReturn(closeStart).thenReturn(closeStart + clodeDelay);
+        eosBetaStreamsProducer.resetProducer();
+        setProducerMetrics(
+            eosBetaMockClientSupplier.producers.get(1),
+            BUFFER_POOL_WAIT_TIME,
+            FLUSH_TME,
+            TXN_INIT_TIME,
+            TXN_BEGIN_TIME,
+            TXN_SEND_OFFSETS_TIME,
+            TXN_COMMIT_TIME,
+            TXN_ABORT_TIME,
+            METADATA_WAIT_TIME
+        );
+
+        assertThat(
+            eosBetaStreamsProducer.totalBlockedTime(),
+            closeTo(2 * expectedTotalBlocked + clodeDelay, 0.01)
+        );
+    }
+
+    private MetricName metricName(final String name) {
+        return new MetricName(name, "", "", Collections.emptyMap());
+    }
+
+    private void addMetric(
+        final MockProducer<?, ?> producer,
+        final String name,
+        final double value) {
+        final MetricName metricName = metricName(name);
+        producer.setMockMetrics(metricName, new Metric() {
+            @Override
+            public MetricName metricName() {
+                return metricName;
+            }
+
+            @Override
+            public Object metricValue() {
+                return value;
+            }
+        });
+    }
+
+    private void setProducerMetrics(
+        final MockProducer<?, ?> producer,
+        final double bufferPoolWaitTime,
+        final double flushTime,
+        final double txnInitTime,
+        final double txnBeginTime,
+        final double txnSendOffsetsTime,
+        final double txnCommitTime,
+        final double txnAbortTime,
+        final double metadataWaitTime) {
+        addMetric(producer, "bufferpool-wait-time-ns-total", bufferPoolWaitTime);
+        addMetric(producer, "flush-time-ns-total", flushTime);
+        addMetric(producer, "txn-init-time-ns-total", txnInitTime);
+        addMetric(producer, "txn-begin-time-ns-total", txnBeginTime);
+        addMetric(producer, "txn-send-offsets-time-ns-total", txnSendOffsetsTime);
+        addMetric(producer, "txn-commit-time-ns-total", txnCommitTime);
+        addMetric(producer, "txn-abort-time-ns-total", txnAbortTime);
+        addMetric(producer, "metadata-wait-time-ns-total", metadataWaitTime);
+    }
 }
